@@ -122,7 +122,7 @@ test_evas_mask(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event
    Elm_Genlist_Item_Class *itc;
    char buf[PATH_MAX];
 
-   win = efl_add_ref(EFL_UI_WIN_CLASS, NULL,
+   win = efl_add(EFL_UI_WIN_CLASS, efl_main_loop_get(),
                  efl_text_set(efl_added, "Evas masking demo"),
                  efl_ui_win_autodel_set(efl_added, 1));
 
