@@ -124,12 +124,12 @@ test_evas_snapshot(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *e
    Eo *win, *table, *o, *snap, *box;
    const char *path;
 
-   win = efl_add_ref(EFL_UI_WIN_CLASS, NULL,
+   win = efl_add(EFL_UI_WIN_CLASS, efl_main_loop_get(),
                  efl_text_set(efl_added, "Evas Snapshot"),
                  efl_ui_win_autodel_set(efl_added, 1));
 
    table = efl_add(EFL_UI_TABLE_CLASS, win,
-                  efl_gfx_arrangement_content_padding_set(efl_added, 5, 5, 1));
+                  efl_gfx_arrangement_content_padding_set(efl_added, 5, 5));
    efl_content_set(win, table);
 
    // Objects below the snapshot
