@@ -336,7 +336,8 @@ test_naviframe(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event
    it = elm_naviframe_item_push(nf, "Page 1", NULL, btn, content, NULL);
    evas_object_data_set(nf, "page1", it);
 
-   evas_object_resize(win, 400, 400);
+   evas_object_resize(win, 400 * elm_config_scale_get(),
+                           400 * elm_config_scale_get());
    evas_object_show(win);
 }
 
@@ -371,7 +372,8 @@ test_naviframe2(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *even
 
    elm_object_item_part_content_set(it, "icon", sc);
 
-   evas_object_resize(win, 400, 400);
+   evas_object_resize(win, 400 * elm_config_scale_get(),
+                           400 * elm_config_scale_get());
    evas_object_show(win);
 }
 
@@ -428,6 +430,7 @@ test_naviframe3(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *even
    evas_object_data_set(tb, "root", it);
    elm_toolbar_item_append(tb, NULL, "Pop all", _bt_pop_all, nf);
 
-   evas_object_resize(win, 400, 400);
+   evas_object_resize(win, 400 * elm_config_scale_get(),
+                           400 * elm_config_scale_get());
    evas_object_show(win);
 }
