@@ -21,6 +21,7 @@ using System.Runtime.InteropServices;
 using System.Collections.Generic;
 using System.Reflection;
 using System.ComponentModel;
+using System.Globalization;
 
 using Eina.Callbacks;
 using static Eina.HashNativeFunctions;
@@ -32,7 +33,7 @@ namespace Eina
 {
 
 [EditorBrowsable(EditorBrowsableState.Never)]
-public enum ElementType
+internal enum ElementType
 {
     NumericType,
     StringType,
@@ -42,23 +43,115 @@ public enum ElementType
 
 [EditorBrowsable(EditorBrowsableState.Never)]
 [StructLayout(LayoutKind.Sequential)]
-public struct InlistMem
+internal struct InlistMem : IEquatable<InlistMem>
 {
     public IntPtr next {get;set;}
     public IntPtr prev {get;set;}
     public IntPtr last {get;set;}
+
+    /// <summary>
+    ///   Gets a hash for <see cref="InlistMem" />.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <returns>A hash code.</returns>
+    public override int GetHashCode()
+        => next.GetHashCode() ^ prev.GetHashCode() ^ last.GetHashCode();
+
+    /// <summary>Returns whether this <see cref="InlistMem" />
+    /// is equal to the given <see cref="object" />.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="other">The <see cref="object" /> to be compared to.</param>
+    /// <returns><c>true</c> if is equal to <c>other</c>.</returns>
+    public override bool Equals(object other)
+        => (!(other is InlistMem)) ? false : Equals((InlistMem)other);
+
+    /// <summary>Returns whether this <see cref="InlistMem" /> is equal
+    /// to the given <see cref="InlistMem" />.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="other">The <see cref="InlistMem" /> to be compared to.</param>
+    /// <returns><c>true</c> if is equal to <c>other</c>.</returns>
+    public bool Equals(InlistMem other)
+        => (next == other.next) && (prev == other.prev)
+        && (last == other.last);
+
+    /// <summary>Returns whether <c>lhs</c> is equal to <c>rhs</c>.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="lhs">The left hand side of the operator.</param>
+    /// <param name="rhs">The right hand side of the operator.</param>
+    /// <returns><c>true</c> if <c>lhs</c> is equal
+    /// to <c>rhs</c>.</returns>
+    public static bool operator==(InlistMem lhs, InlistMem rhs)
+        => lhs.Equals(rhs);
+
+    /// <summary>Returns whether <c>lhs</c> is not equal to <c>rhs</c>.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="lhs">The left hand side of the operator.</param>
+    /// <param name="rhs">The right hand side of the operator.</param>
+    /// <returns><c>true</c> if <c>lhs</c> is not equal
+    /// to <c>rhs</c>.</returns>
+    public static bool operator!=(InlistMem lhs, InlistMem rhs) => !(lhs == rhs);
 }
 
 [EditorBrowsable(EditorBrowsableState.Never)]
 [StructLayout(LayoutKind.Sequential)]
-public struct InlistNode<T>
+internal struct InlistNode<T> : IEquatable<InlistNode<T>>
 {
     public InlistMem __in_list {get;set;}
     public T Val {get;set;}
+
+    /// <summary>
+    ///   Gets a hash for <see cref="InlistNode{T}" />.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <returns>A hash code.</returns>
+    public override int GetHashCode()
+        => __in_list.GetHashCode() ^ Val.GetHashCode();
+
+    /// <summary>Returns whether this <see cref="InlistNode{T}" />
+    /// is equal to the given <see cref="object" />.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="other">The <see cref="object" /> to be compared to.</param>
+    /// <returns><c>true</c> if is equal to <c>other</c>.</returns>
+    public override bool Equals(object other)
+        => (!(other is InlistNode<T>)) ? false : Equals((InlistNode<T>)other);
+
+    /// <summary>Returns whether this <see cref="InlistNode{T}" /> is equal
+    /// to the given <see cref="InlistNode{T}" />.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="other">The <see cref="InlistNode{T}" /> to be compared to.</param>
+    /// <returns><c>true</c> if is equal to <c>other</c>.</returns>
+    public bool Equals(InlistNode<T> other)
+        => (__in_list == other.__in_list) && (Val.Equals(other.Val));
+
+    /// <summary>Returns whether <c>lhs</c> is equal to <c>rhs</c>.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="lhs">The left hand side of the operator.</param>
+    /// <param name="rhs">The right hand side of the operator.</param>
+    /// <returns><c>true</c> if <c>lhs</c> is equal
+    /// to <c>rhs</c>.</returns>
+    public static bool operator==(InlistNode<T> lhs, InlistNode<T> rhs)
+        => lhs.Equals(rhs);
+
+    /// <summary>Returns whether <c>lhs</c> is not equal to <c>rhs</c>.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="lhs">The left hand side of the operator.</param>
+    /// <param name="rhs">The right hand side of the operator.</param>
+    /// <returns><c>true</c> if <c>lhs</c> is not equal
+    /// to <c>rhs</c>.</returns>
+    public static bool operator!=(InlistNode<T> lhs, InlistNode<T> rhs)
+        => !(lhs == rhs);
 }
 
 [EditorBrowsable(EditorBrowsableState.Never)]
-public interface IBaseElementTraits<T>
+internal interface IBaseElementTraits<T>
 {
     IntPtr ManagedToNativeAlloc(T man);
     IntPtr ManagedToNativeAllocInlistNode(T man);
@@ -79,7 +172,7 @@ public interface IBaseElementTraits<T>
 }
 
 [EditorBrowsable(EditorBrowsableState.Never)]
-public class StringElementTraits : IBaseElementTraits<string>
+internal class StringElementTraits : IBaseElementTraits<string>
 {
     public StringElementTraits()
     {
@@ -218,7 +311,7 @@ public class StringElementTraits : IBaseElementTraits<string>
 }
 
 [EditorBrowsable(EditorBrowsableState.Never)]
-public class StringshareElementTraits : IBaseElementTraits<Eina.Stringshare>
+internal class StringshareElementTraits : IBaseElementTraits<Eina.Stringshare>
 {
     public StringshareElementTraits()
     {
@@ -358,7 +451,7 @@ public class StringshareElementTraits : IBaseElementTraits<Eina.Stringshare>
 }
 
 [EditorBrowsable(EditorBrowsableState.Never)]
-public class EflObjectElementTraits<T> : IBaseElementTraits<T>
+internal class EflObjectElementTraits<T> : IBaseElementTraits<T>
 {
     public IntPtr ManagedToNativeAlloc(T man)
     {
@@ -516,7 +609,7 @@ public class EflObjectElementTraits<T> : IBaseElementTraits<T>
 }
 
 [EditorBrowsable(EditorBrowsableState.Never)]
-public abstract class PrimitiveElementTraits<T>
+internal abstract class PrimitiveElementTraits<T>
 {
     private Eina.Callbacks.EinaCompareCb dlgt = null;
 
@@ -618,7 +711,7 @@ public abstract class PrimitiveElementTraits<T>
 }
 
 [EditorBrowsable(EditorBrowsableState.Never)]
-abstract public class Primitive32ElementTraits<T> : PrimitiveElementTraits<T>, IBaseElementTraits<T>
+internal abstract class Primitive32ElementTraits<T> : PrimitiveElementTraits<T>, IBaseElementTraits<T>
 {
     private static IBaseElementTraits<Int32> int32Traits = null;
 
@@ -642,7 +735,7 @@ abstract public class Primitive32ElementTraits<T> : PrimitiveElementTraits<T>, I
 
     public IntPtr ManagedToNativeAllocRef(T man, bool refs)
     {
-        return int32Traits.ManagedToNativeAlloc(Convert.ToInt32((object)man));
+        return int32Traits.ManagedToNativeAlloc(Convert.ToInt32((object)man, CultureInfo.CurrentCulture));
     }
 
     public void NativeFreeRef(IntPtr nat, bool unrefs)
@@ -657,7 +750,7 @@ abstract public class Primitive32ElementTraits<T> : PrimitiveElementTraits<T>, I
 }
 
 [EditorBrowsable(EditorBrowsableState.Never)]
-abstract public class Primitive64ElementTraits<T> : PrimitiveElementTraits<T>, IBaseElementTraits<T>
+internal abstract class Primitive64ElementTraits<T> : PrimitiveElementTraits<T>, IBaseElementTraits<T>
 {
     private static IBaseElementTraits<Int64> int64Traits = null;
 
@@ -681,7 +774,7 @@ abstract public class Primitive64ElementTraits<T> : PrimitiveElementTraits<T>, I
 
     public IntPtr ManagedToNativeAllocRef(T man, bool refs)
     {
-        return int64Traits.ManagedToNativeAlloc(Convert.ToInt64((object)man));
+        return int64Traits.ManagedToNativeAlloc(Convert.ToInt64((object)man, CultureInfo.CurrentCulture));
     }
 
     public void NativeFreeRef(IntPtr nat, bool unrefs)
@@ -696,7 +789,7 @@ abstract public class Primitive64ElementTraits<T> : PrimitiveElementTraits<T>, I
 }
 
 [EditorBrowsable(EditorBrowsableState.Never)]
-public class IntElementTraits : Primitive32ElementTraits<int>, IBaseElementTraits<int>
+internal class IntElementTraits : Primitive32ElementTraits<int>, IBaseElementTraits<int>
 {
     override public void ManagedToNativeCopyTo(int man, IntPtr mem)
     {
@@ -721,7 +814,7 @@ public class IntElementTraits : Primitive32ElementTraits<int>, IBaseElementTrait
 }
 
 [EditorBrowsable(EditorBrowsableState.Never)]
-public class CharElementTraits : Primitive32ElementTraits<char>, IBaseElementTraits<char>
+internal class CharElementTraits : Primitive32ElementTraits<char>, IBaseElementTraits<char>
 {
     override public void ManagedToNativeCopyTo(char man, IntPtr mem)
     {
@@ -746,7 +839,7 @@ public class CharElementTraits : Primitive32ElementTraits<char>, IBaseElementTra
 }
 
 [EditorBrowsable(EditorBrowsableState.Never)]
-public class LongElementTraits : Primitive64ElementTraits<long>, IBaseElementTraits<long>
+internal class LongElementTraits : Primitive64ElementTraits<long>, IBaseElementTraits<long>
 {
     override public void ManagedToNativeCopyTo(long man, IntPtr mem)
     {
@@ -771,7 +864,7 @@ public class LongElementTraits : Primitive64ElementTraits<long>, IBaseElementTra
 }
 
 [EditorBrowsable(EditorBrowsableState.Never)]
-public class ShortElementTraits : Primitive32ElementTraits<short>, IBaseElementTraits<short>
+internal class ShortElementTraits : Primitive32ElementTraits<short>, IBaseElementTraits<short>
 {
     override public void ManagedToNativeCopyTo(short man, IntPtr mem)
     {
@@ -796,7 +889,7 @@ public class ShortElementTraits : Primitive32ElementTraits<short>, IBaseElementT
 }
 
 [EditorBrowsable(EditorBrowsableState.Never)]
-public class FloatElementTraits : Primitive32ElementTraits<float>, IBaseElementTraits<float>
+internal class FloatElementTraits : Primitive32ElementTraits<float>, IBaseElementTraits<float>
 {
     override public void ManagedToNativeCopyTo(float man, IntPtr mem)
     {
@@ -821,7 +914,7 @@ public class FloatElementTraits : Primitive32ElementTraits<float>, IBaseElementT
 }
 
 [EditorBrowsable(EditorBrowsableState.Never)]
-public class DoubleElementTraits : Primitive64ElementTraits<double>, IBaseElementTraits<double>
+internal class DoubleElementTraits : Primitive64ElementTraits<double>, IBaseElementTraits<double>
 {
     override public void ManagedToNativeCopyTo(double man, IntPtr mem)
     {
@@ -846,7 +939,7 @@ public class DoubleElementTraits : Primitive64ElementTraits<double>, IBaseElemen
 }
 
 [EditorBrowsable(EditorBrowsableState.Never)]
-public class ByteElementTraits : Primitive32ElementTraits<byte>, IBaseElementTraits<byte>
+internal class ByteElementTraits : Primitive32ElementTraits<byte>, IBaseElementTraits<byte>
 {
     override public void ManagedToNativeCopyTo(byte man, IntPtr mem)
     {
@@ -871,7 +964,7 @@ public class ByteElementTraits : Primitive32ElementTraits<byte>, IBaseElementTra
 }
 
 [EditorBrowsable(EditorBrowsableState.Never)]
-public static class TraitFunctions
+internal static class TraitFunctions
 {
     public static bool IsEflObject(System.Type type)
     {
@@ -910,22 +1003,6 @@ public static class TraitFunctions
 
     private static IDictionary<System.Type, object> register = new Dictionary<System.Type, object>();
 
-    private static System.Type AsEflInstantiableType(System.Type type)
-    {
-        if (!IsEflObject(type))
-        {
-            return null;
-        }
-
-        if (type.IsInterface)
-        {
-            string fullName = type.FullName + "Concrete";
-            return type.Assembly.GetType(fullName); // That was our best guess...
-        }
-
-        return type; // Not interface, so it should be a concrete.
-    }
-
     public static object RegisterTypeTraits<T>()
     {
         Eina.Log.Debug($"Finding TypeTraits for {typeof(T).Name}");
@@ -933,14 +1010,6 @@ public static class TraitFunctions
         var type = typeof(T);
         if (IsEflObject(type))
         {
-            System.Type concrete = AsEflInstantiableType(type);
-            if (concrete == null || !type.IsAssignableFrom(concrete))
-            {
-                throw new Exception("Failed to get a suitable concrete class for this type.");
-            }
-
-            // No need to pass concrete as the traits class will use reflection to get the actually most
-            // derived type returned.
             traits = new EflObjectElementTraits<T>();
         }
         else if (IsString(type))
