@@ -19,6 +19,7 @@ using System;
 using System.Runtime.InteropServices;
 using System.Collections.Generic;
 using System.ComponentModel;
+using System.Diagnostics.CodeAnalysis;
 
 using static Eina.TraitFunctions;
 using static Eina.IteratorNativeFunctions;
@@ -30,15 +31,61 @@ namespace Eina
 
 [StructLayout(LayoutKind.Sequential)]
 [EditorBrowsable(EditorBrowsableState.Never)]    
-public struct HashTupleNative
+internal struct HashTupleNative : IEquatable<HashTupleNative>
 {
     public IntPtr key;
     public IntPtr data;
     public uint   key_length;
+
+    /// <summary>
+    ///   Gets a hash for <see cref="HashTupleNative" />.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <returns>A hash code.</returns>
+    public override int GetHashCode()
+        => key.GetHashCode() ^ data.GetHashCode() ^ key_length.GetHashCode();
+
+    /// <summary>Returns whether this <see cref="HashTupleNative" />
+    /// is equal to the given <see cref="object" />.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="other">The <see cref="object" /> to be compared to.</param>
+    /// <returns><c>true</c> if is equal to <c>other</c>.</returns>
+    public override bool Equals(object other)
+        => (!(other is HashTupleNative)) ? false : Equals((HashTupleNative)other);
+
+    /// <summary>Returns whether this <see cref="HashTupleNative" /> is equal
+    /// to the given <see cref="HashTupleNative" />.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="other">The <see cref="HashTupleNative" /> to be compared to.</param>
+    /// <returns><c>true</c> if is equal to <c>other</c>.</returns>
+    public bool Equals(HashTupleNative other)
+        => (key == other.key) && (data == other.data)
+        && (key_length == other.key_length);
+
+    /// <summary>Returns whether <c>lhs</c> is equal to <c>rhs</c>.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="lhs">The left hand side of the operator.</param>
+    /// <param name="rhs">The right hand side of the operator.</param>
+    /// <returns><c>true</c> if <c>lhs</c> is equal
+    /// to <c>rhs</c>.</returns>
+    public static bool operator==(HashTupleNative lhs, HashTupleNative rhs)
+        => lhs.Equals(rhs);
+
+    /// <summary>Returns whether <c>lhs</c> is not equal to <c>rhs</c>.
+    /// <para>Since EFL 1.24.</para>
+    /// </summary>
+    /// <param name="lhs">The left hand side of the operator.</param>
+    /// <param name="rhs">The right hand side of the operator.</param>
+    /// <returns><c>true</c> if <c>lhs</c> is not equal
+    /// to <c>rhs</c>.</returns>
+    public static bool operator!=(HashTupleNative lhs, HashTupleNative rhs) => !(lhs == rhs);
 }
 
 [EditorBrowsable(EditorBrowsableState.Never)]
-public static class HashNativeFunctions
+internal static class HashNativeFunctions
 {
     [DllImport(efl.Libs.Eina)] internal static extern IntPtr
         eina_hash_new(IntPtr key_length_cb, IntPtr key_cmp_cb, IntPtr key_hash_cb, IntPtr data_free_cb, int buckets_power_size);
@@ -150,8 +197,10 @@ public static class HashNativeFunctions
 
 /// <summary>Wrapper around native dictionary mapping keys to values.
 ///
-/// Since EFL 1.23.
+/// <para>Since EFL 1.23.</para>
 /// </summary>
+[SuppressMessage("Microsoft.Naming", "CA1710:IdentifiersShouldHaveCorrectSuffix",
+                 Justification = "This is a generalized container mapping the native one.")]
 public class Hash<TKey, TValue> : IEnumerable<KeyValuePair<TKey, TValue>>, IDisposable
 {
     [EditorBrowsable(EditorBrowsableState.Never)]
