@@ -10,10 +10,6 @@
 #include <unistd.h>
 #include <fcntl.h>
 
-#ifdef _WIN32
-# include <Evil.h>
-#endif
-
 #include "Ecore.h"
 #include "ecore_private.h"
 #include "Ecore_Con.h"
@@ -428,7 +424,7 @@ _efl_net_proxy_helper_init(void)
    if (_efl_net_proxy_helper_init_num > 1) return;
    if (_efl_net_proxy_helper_prefix) return;
    _efl_net_proxy_helper_prefix = eina_prefix_new
-     (NULL, ecore_con_init, "ECORE", "ecore", "checkme",
+     (NULL, ecore_con_init, "ECORE_CON", "ecore_con", "checkme",
       PACKAGE_BIN_DIR, PACKAGE_LIB_DIR, PACKAGE_DATA_DIR, PACKAGE_DATA_DIR);
    if (!_efl_net_proxy_helper_queue_lock_init)
      {
