@@ -20,9 +20,6 @@
 #ifdef HAVE_SYS_SOCKET_H
 # include <sys/socket.h>
 #endif
-#ifdef _WIN32
-# include <Evil.h>
-#endif
 
 #define MY_CLASS EFL_NET_SOCKET_FD_CLASS
 
