@@ -53,10 +53,6 @@
 # include <linux/input.h>
 # include <libinput.h>
 
-# ifdef HAVE_SYSTEMD
-#  include <systemd/sd-login.h>
-# endif
-
 # include <Eldbus.h>
 # include <Ecore_Drm.h>
 
@@ -177,7 +173,7 @@ struct _Ecore_Drm_Output
         char serial[13];
      } edid;
 
-   Ecore_Drm_Backlight *backlight;   
+   Ecore_Drm_Backlight *backlight;
    Ecore_Drm_Fb *current, *next;
 
    Eina_Bool primary : 1;
@@ -241,7 +237,7 @@ struct _Ecore_Drm_Evdev
    /*        } pt[EVDEV_MAX_SLOTS]; */
    /*   } abs; */
 
-   struct 
+   struct
      {
         int ix, iy;
         int minx, miny, maxw, maxh;
@@ -253,7 +249,7 @@ struct _Ecore_Drm_Evdev
         uint32_t prev_button, last_button;
      } mouse;
 
-   struct 
+   struct
      {
         struct xkb_keymap *keymap;
         struct xkb_state *state;
@@ -286,7 +282,7 @@ struct _Ecore_Drm_Sprite
    unsigned int crtcs;
    unsigned int plane_id;
 
-   struct 
+   struct
      {
         int x, y;
         unsigned int w, h;
