@@ -53,7 +53,10 @@ eeze_udev_syspath_get_parents(const char *syspath)
      return NULL;
 
    if (!(parent = udev_device_get_parent(device)))
-     return NULL;
+     {
+        udev_device_unref(device);
+        return NULL;
+     }
 
    for (; parent; child = parent, parent = udev_device_get_parent(child))
      {
@@ -78,7 +81,10 @@ eeze_udev_syspath_get_devpath(const char *syspath)
      return NULL;
 
    if (!(name = udev_device_get_devnode(device)))
-     return NULL;
+     {
+        udev_device_unref(device);
+        return NULL;
+     }
 
    name = eina_stringshare_add(name);
    udev_device_unref(device);
@@ -98,7 +104,10 @@ eeze_udev_syspath_get_devname(const char *syspath)
      return NULL;
 
    if (!(name = udev_device_get_sysname(device)))
-     return NULL;
+     {
+        udev_device_unref(device);
+        return NULL;
+     }
 
    name = eina_stringshare_add(name);
    udev_device_unref(device);
