@@ -8,39 +8,7 @@
  * not stable API.
  */
 
-#ifdef EAPI
-# undef EAPI
-#endif
-
-#ifdef _WIN32
-# ifdef EFL_BUILD
-#  ifdef DLL_EXPORT
-#   define EAPI __declspec(dllexport)
-#  else
-#   define EAPI
-#  endif
-# else
-#  define EAPI __declspec(dllimport)
-# endif
-# define EAPI_WEAK
-#else
-# ifdef __GNUC__
-#  if __GNUC__ >= 4
-#   define EAPI __attribute__ ((visibility("default")))
-#   define EAPI_WEAK __attribute__ ((weak))
-#  else
-#   define EAPI
-#   define EAPI_WEAK
-#  endif
-# else
-/**
- * @def EAPI
- * @brief Used to export functions (by changing visibility).
- */
-#  define EAPI
-# endif
-#endif
-
+#include "eina_types.h"
 #include "eina_prefix.h"
 #include "eina_promise.h"
 
@@ -70,9 +38,9 @@ struct _Eina_Vpath_Interface_User
  *
  * @internal
  */
-EAPI void __eina_promise_cancel_all(void);
+EINA_API void __eina_promise_cancel_all(void);
 
-EAPI void __eina_promise_cancel_data(void *data);
+EINA_API void __eina_promise_cancel_data(void *data);
 
 /**
  * Make the app specific paths accessible as virtual path
@@ -89,7 +57,7 @@ EAPI void __eina_promise_cancel_data(void *data);
  *
  * If you do NOT call this api the virtual paths for app.* will be unset
  */
-EAPI void eina_vpath_interface_app_set(const char *app_name, Eina_Prefix *p);
+EINA_API void eina_vpath_interface_app_set(const char *app_name, Eina_Prefix *p);
 
 /**
  * Create the desktop specific vpaths
@@ -98,11 +66,8 @@ EAPI void eina_vpath_interface_app_set(const char *app_name, Eina_Prefix *p);
  *
  * If you do NOT call this api the virtual paths for usr.* will be unset.
  */
-EAPI void eina_vpath_interface_user_set(Eina_Vpath_Interface_User *user);
+EINA_API void eina_vpath_interface_user_set(Eina_Vpath_Interface_User *user);
 
 void eina_xdg_env_init(void);
 
-#undef EAPI
-#define EAPI
-
 #endif
