@@ -25,7 +25,6 @@
 #include <string.h>
 #include <stdlib.h>
 #include <unistd.h>
-#include <fnmatch.h>
 #include <assert.h>
 #include <errno.h>
 
@@ -45,6 +44,7 @@
 
 #include "eina_config.h"
 #include "eina_private.h"
+#include "eina_fnmatch.h"
 #include "eina_inlist.h"
 #include "eina_lock.h"
 #include "eina_thread.h"
@@ -103,8 +103,8 @@ struct _Eina_Log_Timing
    Eina_Log_State state;
 };
 
-EAPI const char *_eina_log_state_init = "init";
-EAPI const char *_eina_log_state_shutdown = "shutdown";
+EINA_API const char *_eina_log_state_init = "init";
+EINA_API const char *_eina_log_state_shutdown = "shutdown";
 
 /*
  * List of levels for domains set by the user before the domains are registered,
@@ -1280,7 +1280,7 @@ finish_register:
      {
         EINA_INLIST_FOREACH(_glob_list, pending)
         {
-           if (!fnmatch(pending->name, name, 0))
+           if (eina_fnmatch(pending->name, name, 0))
              {
                 _log_domains[i].level = pending->level;
                 break;
@@ -1694,13 +1694,13 @@ eina_log_threads_shutdown(void)
  * @cond LOCAL
  */
 
-EAPI int EINA_LOG_DOMAIN_GLOBAL = 0;
+EINA_API int EINA_LOG_DOMAIN_GLOBAL = 0;
 
 /**
  * @endcond
  */
 
-EAPI void
+EINA_API void
 eina_log_threads_enable(void)
 {
 #ifdef EINA_ENABLE_LOG
@@ -1711,7 +1711,7 @@ eina_log_threads_enable(void)
 #endif
 }
 
-EAPI void
+EINA_API void
 eina_log_print_cb_set(Eina_Log_Print_Cb cb, void *data)
 {
 #ifdef EINA_ENABLE_LOG
@@ -1729,7 +1729,7 @@ eina_log_print_cb_set(Eina_Log_Print_Cb cb, void *data)
 #endif
 }
 
-EAPI void
+EINA_API void
 eina_log_level_set(int level)
 {
 #ifdef EINA_ENABLE_LOG
@@ -1742,7 +1742,7 @@ eina_log_level_set(int level)
 #endif
 }
 
-EAPI int
+EINA_API int
 eina_log_level_get(void)
 {
 #ifdef EINA_ENABLE_LOG
@@ -1752,7 +1752,7 @@ eina_log_level_get(void)
 #endif
 }
 
-EAPI Eina_Bool
+EINA_API Eina_Bool
 eina_log_main_thread_check(void)
 {
 #ifdef EINA_ENABLE_LOG
@@ -1762,7 +1762,7 @@ eina_log_main_thread_check(void)
 #endif
 }
 
-EAPI void
+EINA_API void
 eina_log_color_disable_set(Eina_Bool disabled)
 {
 #ifdef EINA_ENABLE_LOG
@@ -1791,7 +1791,7 @@ eina_log_color_disable_set(Eina_Bool disabled)
 #endif
 }
 
-EAPI Eina_Bool
+EINA_API Eina_Bool
 eina_log_color_disable_get(void)
 {
 #ifdef EINA_ENABLE_LOG
@@ -1801,7 +1801,7 @@ eina_log_color_disable_get(void)
 #endif
 }
 
-EAPI void
+EINA_API void
 eina_log_file_disable_set(Eina_Bool disabled)
 {
 #ifdef EINA_ENABLE_LOG
@@ -1811,7 +1811,7 @@ eina_log_file_disable_set(Eina_Bool disabled)
 #endif
 }
 
-EAPI Eina_Bool
+EINA_API Eina_Bool
 eina_log_file_disable_get(void)
 {
 #ifdef EINA_ENABLE_LOG
@@ -1821,7 +1821,7 @@ eina_log_file_disable_get(void)
 #endif
 }
 
-EAPI void
+EINA_API void
 eina_log_function_disable_set(Eina_Bool disabled)
 {
 #ifdef EINA_ENABLE_LOG
@@ -1831,7 +1831,7 @@ eina_log_function_disable_set(Eina_Bool disabled)
 #endif
 }
 
-EAPI Eina_Bool
+EINA_API Eina_Bool
 eina_log_function_disable_get(void)
 {
 #ifdef EINA_ENABLE_LOG
@@ -1841,7 +1841,7 @@ eina_log_function_disable_get(void)
 #endif
 }
 
-EAPI void
+EINA_API void
 eina_log_abort_on_critical_set(Eina_Bool abort_on_critical)
 {
 #ifdef EINA_ENABLE_LOG
@@ -1851,7 +1851,7 @@ eina_log_abort_on_critical_set(Eina_Bool abort_on_critical)
 #endif
 }
 
-EAPI Eina_Bool
+EINA_API Eina_Bool
 eina_log_abort_on_critical_get(void)
 {
 #ifdef EINA_ENABLE_LOG
@@ -1861,7 +1861,7 @@ eina_log_abort_on_critical_get(void)
 #endif
 }
 
-EAPI void
+EINA_API void
 eina_log_abort_on_critical_level_set(int critical_level)
 {
 #ifdef EINA_ENABLE_LOG
@@ -1871,7 +1871,7 @@ eina_log_abort_on_critical_level_set(int critical_level)
 #endif
 }
 
-EAPI int
+EINA_API int
 eina_log_abort_on_critical_level_get(void)
 {
 #ifdef EINA_ENABLE_LOG
@@ -1881,7 +1881,7 @@ eina_log_abort_on_critical_level_get(void)
 #endif
 }
 
-EAPI int
+EINA_API int
 eina_log_domain_register(const char *name, const char *color)
 {
 #ifdef EINA_ENABLE_LOG
@@ -1900,7 +1900,7 @@ eina_log_domain_register(const char *name, const char *color)
 #endif
 }
 
-EAPI void
+EINA_API void
 eina_log_domain_unregister(int domain)
 {
 #ifdef EINA_ENABLE_LOG
@@ -1913,7 +1913,7 @@ eina_log_domain_unregister(int domain)
 #endif
 }
 
-EAPI void
+EINA_API void
 eina_log_domain_level_set(const char *domain_name, int level)
 {
 #ifdef EINA_ENABLE_LOG
@@ -1963,7 +1963,7 @@ eina_log_domain_level_set(const char *domain_name, int level)
 #endif
 }
 
-EAPI int
+EINA_API int
 eina_log_domain_level_get(const char *domain_name)
 {
 #ifdef EINA_ENABLE_LOG
@@ -1996,7 +1996,7 @@ eina_log_domain_level_get(const char *domain_name)
 
    EINA_INLIST_FOREACH(_glob_list, pending)
    {
-      if (!fnmatch(pending->name, domain_name, 0))
+      if (eina_fnmatch(pending->name, domain_name, 0))
          return pending->level;
    }
 
@@ -2007,7 +2007,7 @@ eina_log_domain_level_get(const char *domain_name)
 #endif
 }
 
-EAPI int
+EINA_API int
 eina_log_domain_registered_level_get(int domain)
 {
 #ifdef EINA_ENABLE_LOG
@@ -2023,7 +2023,7 @@ eina_log_domain_registered_level_get(int domain)
 #endif
 }
 
-EAPI void
+EINA_API void
 eina_log_domain_registered_level_set(int domain, int level)
 {
 #ifdef EINA_ENABLE_LOG
@@ -2037,7 +2037,7 @@ eina_log_domain_registered_level_set(int domain, int level)
 #endif
 }
 
-EAPI void
+EINA_API void
 eina_log_print_cb_stderr(const Eina_Log_Domain *d,
                          Eina_Log_Level level,
                          const char *file,
@@ -2072,7 +2072,7 @@ eina_log_print_cb_stderr(const Eina_Log_Domain *d,
 #endif
 }
 
-EAPI void
+EINA_API void
 eina_log_print_cb_stdout(const Eina_Log_Domain *d,
                          Eina_Log_Level level,
                          const char *file,
@@ -2136,7 +2136,7 @@ _eina_sd_init(void)
 
 #endif
 
-EAPI void
+EINA_API void
 eina_log_print_cb_journald(const Eina_Log_Domain *d,
                            Eina_Log_Level level,
                            const char *file,
@@ -2230,7 +2230,7 @@ nosystemd:
    eina_log_print_cb_stderr(d, level, file, fnc, line, fmt, data, args);
 }
 
-EAPI void
+EINA_API void
 eina_log_print_cb_file(const Eina_Log_Domain *d,
                        EINA_UNUSED Eina_Log_Level level,
                        const char *file,
@@ -2274,7 +2274,7 @@ end:
 #endif
 }
 
-EAPI void
+EINA_API void
 eina_log_print(int domain, Eina_Log_Level level, const char *file,
                const char *fnc, int line, const char *fmt, ...)
 {
@@ -2316,7 +2316,7 @@ eina_log_print(int domain, Eina_Log_Level level, const char *file,
 #endif
 }
 
-EAPI void
+EINA_API void
 eina_log_vprint(int domain, Eina_Log_Level level, const char *file,
                 const char *fnc, int line, const char *fmt, va_list args)
 {
@@ -2356,7 +2356,7 @@ eina_log_vprint(int domain, Eina_Log_Level level, const char *file,
 #endif
 }
 
-EAPI void
+EINA_API void
 eina_log_console_color_set(FILE *fp, const char *color)
 {
 #ifdef EINA_ENABLE_LOG
@@ -2392,7 +2392,7 @@ eina_log_console_color_set(FILE *fp, const char *color)
 #endif
 }
 
-EAPI void
+EINA_API void
 eina_log_timing(int domain,
                 Eina_Log_State state,
                 const char *phase)
