@@ -36,7 +36,7 @@
 
 typedef struct _Efl_Ui_Internal_Text_Scroller_Data
 {
-   Efl_Canvas_Text *text_obj;
+   Efl_Canvas_Textblock *text_obj;
    Efl_Ui_Table *text_table;
    Eo *smanager;
 
@@ -63,7 +63,6 @@ _efl_ui_internal_text_scroller_efl_object_constructor(Eo *obj,
                                         Efl_Ui_Internal_Text_Scroller_Data *sd EINA_UNUSED)
 {
    obj = efl_constructor(efl_super(obj, MY_CLASS));
-   //EFL_UI_SCROLLER_DATA_GET_OR_RETURN(obj, psd, NULL);
    efl_ui_scrollbar_bar_mode_set(obj,
          EFL_UI_SCROLLBAR_MODE_OFF, EFL_UI_SCROLLBAR_MODE_OFF);
 
@@ -101,7 +100,7 @@ _efl_ui_internal_text_scroller_efl_canvas_group_group_calculate(Eo *obj,
         efl_event_freeze(sd->text_obj);
         efl_gfx_entity_size_set(sd->text_table, view.size);
         efl_gfx_entity_size_set(sd->text_obj, view.size);
-        efl_canvas_text_size_formatted_get(sd->text_obj, &fsz.w, &fsz.h);
+        fsz = efl_canvas_textblock_size_formatted_get(sd->text_obj);
         efl_gfx_entity_size_set(sd->text_table, sz);
         efl_gfx_entity_size_set(sd->text_obj, sz);
         efl_event_thaw(sd->text_obj);
@@ -138,7 +137,6 @@ _efl_ui_internal_text_scroller_efl_object_finalize(Eo *obj,
    efl_ui_scrollbar_bar_mode_set(obj,
          EFL_UI_SCROLLBAR_MODE_OFF, EFL_UI_SCROLLBAR_MODE_OFF);
    efl_content_set(obj, sd->text_table);
-
    return obj;
 }
 
@@ -152,7 +150,7 @@ _efl_ui_internal_text_scroller_efl_object_destructor(Eo *obj,
 EOLIAN static void
 _efl_ui_internal_text_scroller_initialize(Eo *obj,
                                        Efl_Ui_Internal_Text_Scroller_Data *sd,
-                                       Efl_Canvas_Text *text_obj,
+                                       Efl_Canvas_Textblock *text_obj,
                                        Efl_Ui_Table *text_table)
 {
    if (efl_finalized_get(obj))
@@ -170,16 +168,15 @@ _efl_ui_internal_text_scroller_scroller_mode_set(Eo *obj,
                                        Efl_Ui_Internal_Text_Scroller_Data *sd,
                                        Efl_Ui_Text_Scroller_Mode mode)
 {
-   EFL_UI_SCROLLER_DATA_GET_OR_RETURN(obj, psd);
    sd->mode = mode;
    if (mode == EFL_UI_TEXT_SCROLLER_MODE_MULTILINE)
      {
-        efl_ui_scrollbar_bar_mode_set(psd->smanager,
+        efl_ui_scrollbar_bar_mode_set(obj,
               EFL_UI_SCROLLBAR_MODE_AUTO, EFL_UI_SCROLLBAR_MODE_AUTO);
      }
    else // default (single-line)
      {
-        efl_ui_scrollbar_bar_mode_set(psd->smanager,
+        efl_ui_scrollbar_bar_mode_set(obj,
               EFL_UI_SCROLLBAR_MODE_OFF, EFL_UI_SCROLLBAR_MODE_OFF);
      }
 }
