@@ -4,7 +4,6 @@
 
 #define EFL_ACCESS_OBJECT_PROTECTED
 #define EFL_ACCESS_WIDGET_ACTION_PROTECTED
-#define EFL_ACCESS_VALUE_PROTECTED
 #define ELM_LAYOUT_PROTECTED
 
 #include <Elementary.h>
@@ -37,7 +36,7 @@ _delay_change(void *data)
    efl_event_callback_call(data, EFL_UI_RANGE_EVENT_STEADY, NULL);
 
    if (_elm_config->atspi_mode)
-     efl_access_value_changed_signal_emit(data);
+     efl_access_object_event_emit(data, EFL_UI_RANGE_EVENT_CHANGED, NULL);
 
    return ECORE_CALLBACK_CANCEL;
 }
@@ -48,20 +47,35 @@ _is_horizontal(Efl_Ui_Layout_Orientation dir)
    return efl_ui_layout_orientation_is_horizontal(dir, EINA_TRUE);
 }
 
+static Eina_Bool
+_is_inverted(Eo *obj, Efl_Ui_Slider_Data *sd)
+{
+   Eina_Bool mirrored, inverted;
+
+   mirrored = efl_ui_mirrored_get(obj);
+   inverted = efl_ui_layout_orientation_is_inverted(sd->dir);
+
+   if ((_is_horizontal(sd->dir) && (mirrored ^ inverted)) ||
+       (!_is_horizontal(sd->dir) && inverted))
+     return EINA_TRUE;
+   else
+     return EINA_FALSE;
+}
+
 static void
 _emit_events(Eo *obj, Efl_Ui_Slider_Data *sd)
 {
    efl_event_callback_call(obj, EFL_UI_RANGE_EVENT_CHANGED, NULL);
 
-   if (sd->val == sd->val_min)
+   if (EINA_DBL_EQ(sd->val, sd->val_min))
      efl_event_callback_call(obj, EFL_UI_RANGE_EVENT_MIN_REACHED, NULL);
 
-   if (sd->val == sd->val_max)
+   if (EINA_DBL_EQ(sd->val, sd->val_max))
      efl_event_callback_call(obj, EFL_UI_RANGE_EVENT_MAX_REACHED, NULL);
 
    // emit accessibility event also if value was changed by API
    if (_elm_config->atspi_mode)
-     efl_access_value_changed_signal_emit(obj);
+     efl_access_object_event_emit(obj, EFL_UI_RANGE_EVENT_CHANGED, NULL);
 }
 
 static void
@@ -77,6 +91,21 @@ _user_value_update(Evas_Object *obj, double value)
    evas_object_smart_changed(obj);
 }
 
+static void
+_step_value_update(Evas_Object *obj, double step)
+{
+   double value;
+
+   EFL_UI_SLIDER_DATA_GET(obj, sd);
+
+   if (_is_inverted(obj, sd))
+     step *= -1.0;
+
+   value = CLAMP(sd->val + step, sd->val_min, sd->val_max);
+   _user_value_update(obj, value);
+
+}
+
 static void
 _drag_value_fetch(Evas_Object *obj)
 {
@@ -90,10 +119,8 @@ _drag_value_fetch(Evas_Object *obj)
    if (_is_horizontal(sd->dir)) pos = posx;
    else pos = posy;
 
-   if (efl_ui_mirrored_get(obj) ^ efl_ui_layout_orientation_is_inverted(sd->dir))
-     {
-        pos = 1.0 - pos;
-     }
+   if (_is_inverted(obj, sd))
+     pos = 1.0 - pos;
 
    val = (pos * (sd->val_max - sd->val_min)) + sd->val_min;
 
@@ -106,7 +133,7 @@ _drag_value_fetch(Evas_Object *obj)
 static void
 _adjust_to_step(Efl_Ui_Slider *obj,  Efl_Ui_Slider_Data *pd)
 {
-   if (pd->step)
+   if (EINA_DBL_NONZERO(pd->step))
      {
         double relative_step = pd->step/(pd->val_max - pd->val_min);
         double new_value = (round(pd->val/relative_step))*relative_step;
@@ -124,10 +151,8 @@ _drag_value_update(Evas_Object *obj)
 
    pos = (sd->val - sd->val_min) / (sd->val_max - sd->val_min);
 
-   if (efl_ui_mirrored_get(obj) ^ efl_ui_layout_orientation_is_inverted(sd->dir))
-     {
-        pos = 1.0 - pos;
-     }
+   if (_is_inverted(obj, sd))
+     pos = 1.0 - pos;
 
    efl_ui_drag_value_set(efl_part(wd->resize_obj, "efl.draggable.slider"),
                            pos, pos);
@@ -194,7 +219,8 @@ _drag_up(Evas_Object *obj)
 
    efl_ui_drag_step_move(efl_part(wd->resize_obj, "efl.draggable.slider"),
                            relative_step, relative_step);
-   _drag_value_fetch(obj);
+
+   _step_value_update(obj, step);
 }
 
 static void
@@ -214,7 +240,8 @@ _drag_down(Evas_Object *obj)
 
    efl_ui_drag_step_move(efl_part(wd->resize_obj, "efl.draggable.slider"),
                            relative_step, relative_step);
-   _drag_value_fetch(obj);
+
+   _step_value_update(obj, step);
 }
 
 static Eina_Bool
@@ -750,7 +777,7 @@ _efl_ui_slider_efl_ui_range_interactive_range_step_set(Eo *obj EINA_UNUSED, Efl_
         return;
      }
 
-   if (sd->step == step) return;
+   if (EINA_DBL_EQ(sd->step, step)) return;
 
    sd->step = step;
 }
@@ -767,45 +794,6 @@ _efl_ui_slider_efl_ui_focus_object_on_focus_update(Eo *obj, Efl_Ui_Slider_Data *
 
 // A11Y Accessibility
 
-EOLIAN static void
-_efl_ui_slider_efl_access_value_value_and_text_get(const Eo *obj EINA_UNUSED, Efl_Ui_Slider_Data *sd, double *value, const char **text)
-{
-   if (value) *value = sd->val;
-   if (text) *text = NULL;
-}
-
-EOLIAN static Eina_Bool
-_efl_ui_slider_efl_access_value_value_and_text_set(Eo *obj, Efl_Ui_Slider_Data *sd, double value, const char *text EINA_UNUSED)
-{
-   if (value < sd->val_min) value = sd->val_min;
-   if (value > sd->val_max) value = sd->val_max;
-
-   efl_event_callback_call(obj, EFL_UI_SLIDER_EVENT_SLIDER_DRAG_START, NULL);
-
-   if (fabs(value - sd->val) > DBL_EPSILON)
-     {
-        _user_value_update(obj, value);
-     }
-
-   efl_event_callback_call(obj, EFL_UI_SLIDER_EVENT_SLIDER_DRAG_STOP, NULL);
-
-   return EINA_TRUE;
-}
-
-EOLIAN static void
-_efl_ui_slider_efl_access_value_range_get(const Eo *obj EINA_UNUSED, Efl_Ui_Slider_Data *sd, double *lower, double *upper, const char **descr)
-{
-   if (lower) *lower = sd->val_min;
-   if (upper) *upper = sd->val_max;
-   if (descr) *descr = NULL;
-}
-
-EOLIAN static double
-_efl_ui_slider_efl_access_value_increment_get(const Eo *obj EINA_UNUSED, Efl_Ui_Slider_Data *sd)
-{
-   return sd->step;
-}
-
 EOLIAN const Efl_Access_Action_Data *
 _efl_ui_slider_efl_access_widget_action_elm_actions_get(const Eo *obj EINA_UNUSED, Efl_Ui_Slider_Data *pd EINA_UNUSED)
 {
