@@ -128,7 +128,7 @@ typedef struct _Elm_Calendar_Mark Elm_Calendar_Mark;
  */
 #define ELM_CALENDAR_CLASS elm_calendar_class_get()
 
-EWAPI const Efl_Class *elm_calendar_class_get(void);
+EWAPI const Efl_Class *elm_calendar_class_get(void) EINA_CONST;
 
 /**
  * @brief The first day of week to use on calendar widgets'.
@@ -189,7 +189,7 @@ EOAPI void elm_obj_calendar_selectable_set(Eo *obj, Elm_Calendar_Selectable sele
 EOAPI Elm_Calendar_Selectable elm_obj_calendar_selectable_get(const Eo *obj);
 
 /**
- * @brief The interval on time updates for an user mouse button hold on
+ * @brief The interval on time updates for a user mouse button hold on
  * calendar widgets' month/year selection.
  *
  * This interval value is decreased while the user holds the mouse pointer
@@ -213,7 +213,7 @@ EOAPI Elm_Calendar_Selectable elm_obj_calendar_selectable_get(const Eo *obj);
 EOAPI void elm_obj_calendar_interval_set(Eo *obj, double interval);
 
 /**
- * @brief The interval on time updates for an user mouse button hold on
+ * @brief The interval on time updates for a user mouse button hold on
  * calendar widgets' month/year selection.
  *
  * This interval value is decreased while the user holds the mouse pointer
