@@ -627,13 +627,13 @@ _time_update(Evas_Object *obj, Eina_Bool theme_update)
      sd->cur.ampm = -1;
 }
 
-EOLIAN static Efl_Ui_Theme_Apply
+EOLIAN static Eina_Error
 _elm_clock_efl_ui_widget_theme_apply(Eo *obj, Elm_Clock_Data *sd EINA_UNUSED)
 {
-   Efl_Ui_Theme_Apply int_ret = EFL_UI_THEME_APPLY_FAILED;
+   Eina_Error int_ret = EFL_UI_THEME_APPLY_ERROR_GENERIC;
 
    int_ret = efl_ui_widget_theme_apply(efl_super(obj, MY_CLASS));
-   if (!int_ret) return EFL_UI_THEME_APPLY_FAILED;
+   if (int_ret == EFL_UI_THEME_APPLY_ERROR_GENERIC) return int_ret;
 
    _time_update(obj, EINA_TRUE);
 
@@ -722,7 +722,6 @@ _elm_clock_efl_canvas_group_group_add(Eo *obj, Elm_Clock_Data *priv)
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
    efl_canvas_group_add(efl_super(obj, MY_CLASS));
-   elm_widget_sub_object_parent_add(obj);
 
    priv->cur.ampm = -1;
    priv->cur.seconds = EINA_TRUE;
@@ -808,6 +807,7 @@ _elm_clock_efl_object_constructor(Eo *obj, Elm_Clock_Data *_pd EINA_UNUSED)
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
    efl_access_object_role_set(obj, EFL_ACCESS_ROLE_TEXT);
+   legacy_child_focus_handle(obj);
 
    return obj;
 }
@@ -963,4 +963,4 @@ _elm_clock_class_constructor(Efl_Class *klass)
 #define ELM_CLOCK_EXTRA_OPS \
    EFL_CANVAS_GROUP_ADD_DEL_OPS(elm_clock)
 
-#include "elm_clock.eo.c"
+#include "elm_clock_eo.c"
