@@ -69,7 +69,7 @@ typedef enum
  */
 #define ELM_MAP_CLASS elm_map_class_get()
 
-EWAPI const Efl_Class *elm_map_class_get(void);
+EWAPI const Efl_Class *elm_map_class_get(void) EINA_CONST;
 
 /**
  * @brief Set the minimum zoom of the source.
@@ -339,7 +339,7 @@ EOAPI Elm_Map_Overlay *elm_obj_map_overlay_circle_add(Eo *obj, double lon, doubl
  * have default style layouts at first.
  *
  * You can change the state (hidden, paused, etc.) or set the content or icon
- * of the group overlays by chaning the state of the class overlay. Do not
+ * of the group overlays by changing the state of the class overlay. Do not
  * modify the group overlay itself.
  *
  * Also these changes have a influence on the overlays in the same class even
