@@ -1,6 +1,114 @@
 #include "elput_private.h"
 
-#if defined(HAVE_SYSTEMD) || defined(HAVE_ELOGIND)
+#ifdef HAVE_SYSTEMD
+
+# ifdef major
+#  define MAJOR(x) major(x)
+# else
+#  define MAJOR(x) ((((x) >> 8) & 0xfff) | (((x) >> 32) & ~0xfff))
+# endif
+
+# ifdef minor
+#  define MINOR(x) minor(x)
+# else
+#  define MINOR(x) (((x) & 0xff) | (((x) >> 12) & ~0xff))
+# endif
+
+static Eina_Module *_libsystemd = NULL;
+static Eina_Bool _libsystemd_broken = EINA_FALSE;
+
+static int (*_elput_sd_session_get_vt) (const char *session, unsigned *vtnr) = NULL;
+static int (*_elput_sd_session_get_tty) (const char *session, char **display) = NULL;
+static int (*_elput_sd_pid_get_session) (pid_t pid, char **session) = NULL;
+static int (*_elput_sd_session_get_seat) (const char *session, char **seat) = NULL;
+static int (*_elput_sd_seat_can_tty) (const char *seat) = NULL;
+
+void
+_elput_sd_init(void)
+{
+   if (_libsystemd_broken) return;
+   _libsystemd = eina_module_new("libsystemd.so.0");
+   if (_libsystemd)
+     {
+        if (!eina_module_load(_libsystemd))
+          {
+             eina_module_free(_libsystemd);
+             _libsystemd = NULL;
+          }
+     }
+   if (!_libsystemd)
+     {
+        const char *s = getenv("EFL_ELOGIND_LIB");
+
+        if (s)
+          {
+             _libsystemd = eina_module_new(s);
+             if (_libsystemd)
+               {
+                  if (!eina_module_load(_libsystemd))
+                    {
+                       eina_module_free(_libsystemd);
+                       _libsystemd = NULL;
+                    }
+               }
+          }
+        if (!_libsystemd)
+          {
+             _libsystemd = eina_module_new("libelogind-shared.so.0");
+             if (_libsystemd)
+               {
+                  if (!eina_module_load(_libsystemd))
+                    {
+                       eina_module_free(_libsystemd);
+                       _libsystemd = NULL;
+                    }
+               }
+          }
+        if (!_libsystemd)
+          {
+             _libsystemd = eina_module_new("libelogind.so.0");
+             if (_libsystemd)
+               {
+                  if (!eina_module_load(_libsystemd))
+                    {
+                       eina_module_free(_libsystemd);
+                       _libsystemd = NULL;
+                    }
+               }
+          }
+     }
+   if (!_libsystemd)
+     {
+        _libsystemd_broken = EINA_TRUE;
+        return;
+     }
+   // sd_session_get_vt == newer in systemd 207
+   _elput_sd_session_get_vt =
+     eina_module_symbol_get(_libsystemd, "sd_session_get_vt");
+   // sd_session_get_tty == older api in ssystemd 198
+   _elput_sd_session_get_tty =
+     eina_module_symbol_get(_libsystemd, "sd_session_get_tty");
+   _elput_sd_pid_get_session =
+     eina_module_symbol_get(_libsystemd, "sd_pid_get_session");
+   _elput_sd_session_get_seat =
+     eina_module_symbol_get(_libsystemd, "sd_session_get_seat");
+   _elput_sd_seat_can_tty =
+     eina_module_symbol_get(_libsystemd, "sd_seat_can_tty");
+   if (((!_elput_sd_session_get_vt) && (!_elput_sd_session_get_tty)) ||
+       (!_elput_sd_pid_get_session) ||
+       (!_elput_sd_session_get_seat) || (!_elput_sd_seat_can_tty))
+     {
+        _elput_sd_session_get_vt = NULL;
+        _elput_sd_session_get_tty = NULL;
+        _elput_sd_pid_get_session = NULL;
+        _elput_sd_session_get_seat = NULL;
+       _elput_sd_seat_can_tty = NULL;
+        eina_module_free(_libsystemd);
+        _libsystemd = NULL;
+        _libsystemd_broken = EINA_TRUE;
+     }
+}
+
 
 static void
 _logind_session_active_cb_free(void *data EINA_UNUSED, void *event)
@@ -140,13 +248,16 @@ _cb_device_resumed(void *data, const Eldbus_Message *msg)
 static Eina_Bool
 _logind_session_vt_get(const char *sid, unsigned int *vt)
 {
-# ifdef HAVE_SYSTEMD_LOGIN_209
-   return (sd_session_get_vt(sid, vt) >= 0);
-# else
    int ret = 0;
    char *tty;
 
-   ret = sd_session_get_tty(sid, &tty);
+   _elput_sd_init();
+   if ((!_elput_sd_session_get_vt) && (!_elput_sd_session_get_tty))
+     return EINA_FALSE;
+   if (_elput_sd_session_get_vt)
+     return (_elput_sd_session_get_vt(sid, vt) >= 0);
+
+   ret = _elput_sd_session_get_tty(sid, &tty);
    if (ret < 0) return ret;
 
    ret = sscanf(tty, "tty%u", vt);
@@ -154,7 +265,6 @@ _logind_session_vt_get(const char *sid, unsigned int *vt)
 
    if (ret != 1) return EINA_FALSE;
    return EINA_TRUE;
-# endif
 }
 
 static Eina_Bool
@@ -489,13 +599,16 @@ _logind_connect(Elput_Manager **manager, const char *seat, unsigned int tty)
    int ret = 0;
    char *s = NULL;
 
+   _elput_sd_init();
+   if (!_elput_sd_pid_get_session) return EINA_FALSE;
+
    em = calloc(1, sizeof(Elput_Manager));
    if (!em) return EINA_FALSE;
 
    em->interface = &_logind_interface;
    em->seat = eina_stringshare_add(seat);
 
-   ret = sd_pid_get_session(getpid(), &em->sid);
+   ret = _elput_sd_pid_get_session(getpid(), &em->sid);
 
    if (ret < 0)
      {
@@ -508,7 +621,7 @@ _logind_connect(Elput_Manager **manager, const char *seat, unsigned int tty)
 
    if (!em->sid) goto session_err;
 
-   ret = sd_session_get_seat(em->sid, &s);
+   ret = _elput_sd_session_get_seat(em->sid, &s);
    if (ret < 0)
      {
         ERR("Failed to get session seat");
@@ -522,7 +635,7 @@ _logind_connect(Elput_Manager **manager, const char *seat, unsigned int tty)
         goto seat_err;
      }
 
-   if ((seat) && (!strcmp(seat, "seat0")))
+   if ((seat) && (_elput_sd_seat_can_tty(seat)))
      {
         if (!_logind_session_vt_get(em->sid, &em->vt_num))
           {
@@ -606,7 +719,7 @@ _logind_open_async(Elput_Manager *em, const char *path, int flags)
    if ((stat(path, &st) < 0) || (!S_ISCHR(st.st_mode)))
      _logind_pipe_write_fd(em, fd);
    else
-     _logind_device_take_async(em, flags, major(st.st_rdev), minor(st.st_rdev));
+     _logind_device_take_async(em, flags, MAJOR(st.st_rdev), MINOR(st.st_rdev));
 }
 
 static int
@@ -621,10 +734,10 @@ _logind_open(Elput_Manager *em, const char *path, int flags)
 
    if (!S_ISCHR(st.st_mode)) return -1;
 
-   fd = _logind_device_take(em, major(st.st_rdev), minor(st.st_rdev));
+   fd = _logind_device_take(em, MAJOR(st.st_rdev), MINOR(st.st_rdev));
    if (fd < 0) return fd;
 
-   if (major(st.st_rdev) == 226) //DRM_MAJOR
+   if (MAJOR(st.st_rdev) == 226) //DRM_MAJOR
      em->drm_opens++;
 
    fl = fcntl(fd, F_GETFL);
@@ -640,7 +753,7 @@ _logind_open(Elput_Manager *em, const char *path, int flags)
 
 err:
    close(fd);
-   _logind_device_release(em, major(st.st_rdev), minor(st.st_rdev));
+   _logind_device_release(em, MAJOR(st.st_rdev), MINOR(st.st_rdev));
    return -1;
 }
 
@@ -656,7 +769,7 @@ _logind_close(Elput_Manager *em, int fd)
 
    if (!S_ISCHR(st.st_mode)) return;
 
-   _logind_device_release(em, major(st.st_rdev), minor(st.st_rdev));
+   _logind_device_release(em, MAJOR(st.st_rdev), MINOR(st.st_rdev));
 }
 
 static Eina_Bool
