@@ -6,28 +6,28 @@
 #include "eolian_database.h"
 #include "eo_lexer.h"
 
-EAPI Eolian_Type_Type
+EOLIAN_API Eolian_Type_Type
 eolian_type_type_get(const Eolian_Type *tp)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(tp, EOLIAN_TYPE_UNKNOWN_TYPE);
    return tp->type;
 }
 
-EAPI Eolian_Type_Builtin_Type
+EOLIAN_API Eolian_Type_Builtin_Type
 eolian_type_builtin_type_get(const Eolian_Type *tp)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(tp, EOLIAN_TYPE_BUILTIN_INVALID);
    return tp->btype;
 }
 
-EAPI Eolian_Typedecl_Type
+EOLIAN_API Eolian_Typedecl_Type
 eolian_typedecl_type_get(const Eolian_Typedecl *tp)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(tp, EOLIAN_TYPEDECL_UNKNOWN);
    return tp->type;
 }
 
-EAPI Eina_Iterator *
+EOLIAN_API Eina_Iterator *
 eolian_typedecl_struct_fields_get(const Eolian_Typedecl *tp)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(tp, NULL);
@@ -36,7 +36,7 @@ eolian_typedecl_struct_fields_get(const Eolian_Typedecl *tp)
    return eina_list_iterator_new(tp->field_list);
 }
 
-EAPI const Eolian_Struct_Type_Field *
+EOLIAN_API const Eolian_Struct_Type_Field *
 eolian_typedecl_struct_field_get(const Eolian_Typedecl *tp, const char *field)
 {
    Eolian_Struct_Type_Field *sf = NULL;
@@ -49,35 +49,35 @@ eolian_typedecl_struct_field_get(const Eolian_Typedecl *tp, const char *field)
    return sf;
 }
 
-EAPI const Eolian_Documentation *
+EOLIAN_API const Eolian_Documentation *
 eolian_typedecl_struct_field_documentation_get(const Eolian_Struct_Type_Field *fl)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(fl, NULL);
    return fl->doc;
 }
 
-EAPI const Eolian_Type *
+EOLIAN_API const Eolian_Type *
 eolian_typedecl_struct_field_type_get(const Eolian_Struct_Type_Field *fl)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(fl, NULL);
    return fl->type;
 }
 
-EAPI Eina_Bool
+EOLIAN_API Eina_Bool
 eolian_typedecl_struct_field_is_by_ref(const Eolian_Struct_Type_Field *fl)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(fl, EINA_FALSE);
    return fl->by_ref;
 }
 
-EAPI Eina_Bool
+EOLIAN_API Eina_Bool
 eolian_typedecl_struct_field_is_move(const Eolian_Struct_Type_Field *fl)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(fl, EINA_FALSE);
    return fl->move;
 }
 
-EAPI Eina_Stringshare *
+EOLIAN_API Eina_Stringshare *
 eolian_typedecl_struct_field_c_type_get(const Eolian_Struct_Type_Field *fl)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(fl, NULL);
@@ -88,7 +88,7 @@ eolian_typedecl_struct_field_c_type_get(const Eolian_Struct_Type_Field *fl)
    return ret;
 }
 
-EAPI Eina_Iterator *
+EOLIAN_API Eina_Iterator *
 eolian_typedecl_enum_fields_get(const Eolian_Typedecl *tp)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(tp, NULL);
@@ -97,7 +97,7 @@ eolian_typedecl_enum_fields_get(const Eolian_Typedecl *tp)
    return eina_list_iterator_new(tp->field_list);
 }
 
-EAPI const Eolian_Enum_Type_Field *
+EOLIAN_API const Eolian_Enum_Type_Field *
 eolian_typedecl_enum_field_get(const Eolian_Typedecl *tp, const char *field)
 {
    Eolian_Enum_Type_Field *ef = NULL;
@@ -110,7 +110,7 @@ eolian_typedecl_enum_field_get(const Eolian_Typedecl *tp, const char *field)
    return ef;
 }
 
-EAPI Eina_Stringshare *
+EOLIAN_API Eina_Stringshare *
 eolian_typedecl_enum_field_c_constant_get(const Eolian_Enum_Type_Field *fl)
 {
    Eina_Stringshare *ret;
@@ -133,14 +133,14 @@ eolian_typedecl_enum_field_c_constant_get(const Eolian_Enum_Type_Field *fl)
    return ret;
 }
 
-EAPI const Eolian_Documentation *
+EOLIAN_API const Eolian_Documentation *
 eolian_typedecl_enum_field_documentation_get(const Eolian_Enum_Type_Field *fl)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(fl, NULL);
    return fl->doc;
 }
 
-EAPI const Eolian_Expression *
+EOLIAN_API const Eolian_Expression *
 eolian_typedecl_enum_field_value_get(const Eolian_Enum_Type_Field *fl, Eina_Bool force)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(fl, NULL);
@@ -148,7 +148,7 @@ eolian_typedecl_enum_field_value_get(const Eolian_Enum_Type_Field *fl, Eina_Bool
    return fl->value;
 }
 
-EAPI const char *
+EOLIAN_API const char *
 eolian_typedecl_enum_legacy_prefix_get(const Eolian_Typedecl *tp)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(tp, NULL);
@@ -157,28 +157,28 @@ eolian_typedecl_enum_legacy_prefix_get(const Eolian_Typedecl *tp)
    return tp->legacy;
 }
 
-EAPI const Eolian_Documentation *
+EOLIAN_API const Eolian_Documentation *
 eolian_typedecl_documentation_get(const Eolian_Typedecl *tp)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(tp, NULL);
    return tp->doc;
 }
 
-EAPI const Eolian_Type *
+EOLIAN_API const Eolian_Type *
 eolian_type_base_type_get(const Eolian_Type *tp)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(tp, NULL);
    return tp->base_type;
 }
 
-EAPI const Eolian_Type *
+EOLIAN_API const Eolian_Type *
 eolian_type_next_type_get(const Eolian_Type *tp)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(tp, NULL);
    return tp->next_type;
 }
 
-EAPI const Eolian_Typedecl *
+EOLIAN_API const Eolian_Typedecl *
 eolian_type_typedecl_get(const Eolian_Type *tp)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(tp, NULL);
@@ -187,14 +187,14 @@ eolian_type_typedecl_get(const Eolian_Type *tp)
    return tp->tdecl;
 }
 
-EAPI const Eolian_Type *
+EOLIAN_API const Eolian_Type *
 eolian_typedecl_base_type_get(const Eolian_Typedecl *tp)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(tp, NULL);
    return tp->base_type;
 }
 
-EAPI const Eolian_Type *
+EOLIAN_API const Eolian_Type *
 eolian_type_aliased_base_get(const Eolian_Type *tp)
 {
    if (!tp || tp->type != EOLIAN_TYPE_REGULAR || tp->is_ptr)
@@ -205,7 +205,7 @@ eolian_type_aliased_base_get(const Eolian_Type *tp)
    return tp;
 }
 
-EAPI const Eolian_Type *
+EOLIAN_API const Eolian_Type *
 eolian_typedecl_aliased_base_get(const Eolian_Typedecl *tp)
 {
    if (!tp || tp->type != EOLIAN_TYPEDECL_ALIAS)
@@ -213,7 +213,7 @@ eolian_typedecl_aliased_base_get(const Eolian_Typedecl *tp)
    return eolian_type_aliased_base_get(tp->base_type);
 }
 
-EAPI const Eolian_Class *
+EOLIAN_API const Eolian_Class *
 eolian_type_class_get(const Eolian_Type *tp)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(tp, NULL);
@@ -222,7 +222,7 @@ eolian_type_class_get(const Eolian_Type *tp)
    return tp->klass;
 }
 
-EAPI const Eolian_Error *
+EOLIAN_API const Eolian_Error *
 eolian_type_error_get(const Eolian_Type *tp)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(tp, NULL);
@@ -231,35 +231,35 @@ eolian_type_error_get(const Eolian_Type *tp)
    return tp->error;
 }
 
-EAPI Eina_Bool
+EOLIAN_API Eina_Bool
 eolian_type_is_move(const Eolian_Type *tp)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(tp, EINA_FALSE);
    return tp->move;
 }
 
-EAPI Eina_Bool
+EOLIAN_API Eina_Bool
 eolian_type_is_const(const Eolian_Type *tp)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(tp, EINA_FALSE);
    return tp->is_const;
 }
 
-EAPI Eina_Bool
+EOLIAN_API Eina_Bool
 eolian_type_is_ptr(const Eolian_Type *tp)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(tp, EINA_FALSE);
    return tp->is_ptr;
 }
 
-EAPI Eina_Bool
+EOLIAN_API Eina_Bool
 eolian_typedecl_is_extern(const Eolian_Typedecl *tp)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(tp, EINA_FALSE);
    return tp->is_extern;
 }
 
-EAPI Eina_Stringshare *
+EOLIAN_API Eina_Stringshare *
 eolian_type_c_type_get(const Eolian_Type *tp)
 {
    Eina_Stringshare *ret;
@@ -272,7 +272,7 @@ eolian_type_c_type_get(const Eolian_Type *tp)
    return ret;
 }
 
-EAPI Eina_Stringshare *
+EOLIAN_API Eina_Stringshare *
 eolian_typedecl_c_type_get(const Eolian_Typedecl *tp)
 {
    Eina_Stringshare *ret;
@@ -285,14 +285,14 @@ eolian_typedecl_c_type_get(const Eolian_Typedecl *tp)
    return ret;
 }
 
-EAPI const char *
+EOLIAN_API const char *
 eolian_typedecl_free_func_get(const Eolian_Typedecl *tp)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(tp, NULL);
    return tp->freefunc;
 }
 
-EAPI const Eolian_Function *
+EOLIAN_API const Eolian_Function *
 eolian_typedecl_function_pointer_get(const Eolian_Typedecl *tp)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(tp, NULL);
