@@ -1462,6 +1462,7 @@ evas_object_smart_del(Evas_Object *eo_obj)
    free(sobj->interface_privates);
    sobj->interface_privates = NULL;
 
+   sobj->data = NULL;
    if (s) evas_object_smart_unuse(s);
 }
 
@@ -1673,6 +1674,12 @@ evas_object_smart_cleanup(Evas_Object *eo_obj)
                     }
                }
              else evas_object_smart_member_del(contained_obj);
+             // EEK ... it qasn't removed? remove it forcibly...
+             if ((Evas_Object_Protected_Data *)o->contained == contained)
+               {
+                  o->contained = eina_inlist_remove
+                    (o->contained, EINA_INLIST_GET(contained));
+               }
           }
 
         while (o->callbacks)
