@@ -27,6 +27,9 @@
 #ifdef BUILD_ECORE_EVAS_SOFTWARE_DDRAW
 # include <Evas_Engine_Software_DDraw.h>
 #endif
+#ifdef BUILD_ECORE_EVAS_OPENGL_WIN32
+# include <Evas_Engine_GL_Win32.h>
+#endif
 
 #ifdef _WIN32
 # ifndef EFL_MODULE_STATIC
@@ -756,6 +759,22 @@ _ecore_evas_win32_rotation_set(Ecore_Evas *ee, int rotation, int resize EINA_UNU
         _ecore_evas_win32_rotation_set_internal(ee, rotation);
      }
 #endif /* BUILD_ECORE_EVAS_SOFTWARE_DDRAW */
+
+#ifdef BUILD_ECORE_EVAS_OPENGL_WIN32
+   if (!strcmp(ee->driver, "opengl_win32"))
+     {
+        Evas_Engine_Info_GL_Win32 *einfo;
+
+        einfo = (Evas_Engine_Info_GL_Win32 *)evas_engine_info_get(ee->evas);
+        if (!einfo) return;
+        einfo->info.rotation = rotation;
+        if (!evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo))
+          {
+             ERR("evas_engine_info_set() for engine '%s' failed.", ee->driver);
+          }
+        _ecore_evas_win32_rotation_set_internal(ee, rotation);
+     }
+#endif /* BUILD_ECORE_EVAS_SOFTWARE_GDI */
 }
 
 static void
@@ -1030,6 +1049,7 @@ _ecore_evas_win32_fullscreen_set(Ecore_Evas *ee, Eina_Bool on)
      _ecore_evas_win32_state_update(ee);
 
    /* Nothing to be done for the GDI backend at the evas level */
+   /* Nothing to be done for the OpenGL backend at the evas level */
 
 #ifdef BUILD_ECORE_EVAS_SOFTWRE_DDRAW
    if (strcmp(ee->driver, "software_ddraw") == 0)
@@ -1546,6 +1566,45 @@ _ecore_evas_engine_software_ddraw_init(Ecore_Evas *ee)
 }
 #endif /* BUILD_ECORE_EVAS_SOFTWARE_DDRAW */
 
+#ifdef BUILD_ECORE_EVAS_OPENGL_WIN32
+static int
+_ecore_evas_engine_opengl_win32_init(Ecore_Evas *ee)
+{
+   Evas_Engine_Info_GL_Win32 *einfo;
+   const char                *driver;
+   int                        rmethod;
+
+   driver = "gl_win32";
+
+   rmethod = evas_render_method_lookup(driver);
+   if (!rmethod)
+     return 0;
+
+   ee->driver = driver;
+   evas_output_method_set(ee->evas, rmethod);
+
+   einfo = (Evas_Engine_Info_GL_Win32 *)evas_engine_info_get(ee->evas);
+   if (einfo)
+     {
+        /* FIXME: REDRAW_DEBUG missing for now */
+        einfo->info.window = ((Ecore_Win32_Window *)ee->prop.window)->window;
+        einfo->info.rotation = 0;
+        if (!evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo))
+          {
+             ERR("evas_engine_info_set() for engine '%s' failed.", ee->driver);
+             return 0;
+          }
+     }
+   else
+     {
+        ERR("evas_engine_info_set() init engine '%s' failed.", ee->driver);
+        return 0;
+     }
+
+   return 1;
+}
+#endif /* BUILD_ECORE_EVAS_OPENGL_WIN32 */
+
 static Ecore_Evas *
 _ecore_evas_win32_new_internal(int (*_ecore_evas_engine_backend_init)(Ecore_Evas *ee),
                                Ecore_Win32_Window *parent,
@@ -1680,6 +1739,30 @@ ecore_evas_software_ddraw_new_internal(Ecore_Win32_Window *parent,
 #endif /* ! BUILD_ECORE_EVAS_SOFTWARE_DDRAW */
 }
 
+EMODAPI Ecore_Evas *
+ecore_evas_gl_win32_new_internal(Ecore_Win32_Window *parent,
+                                 int                 x,
+                                 int                 y,
+                                 int                 width,
+                                 int                 height)
+{
+#ifdef BUILD_ECORE_EVAS_OPENGL_WIN32
+   return _ecore_evas_win32_new_internal(_ecore_evas_engine_opengl_win32_init,
+                                         parent,
+                                         x,
+                                         y,
+                                         width,
+                                         height);
+#else
+   (void) parent;
+   (void) x;
+   (void) y;
+   (void) width;
+   (void) height;
+   return NULL;
+#endif
+}
+
 static Ecore_Win32_Window *
 _ecore_evas_win32_window_get(const Ecore_Evas *ee)
 {
