@@ -709,10 +709,7 @@ Evas_GL_Program  *evas_gl_common_shader_program_get(Evas_Engine_GL_Context *gc,
                                                     Shader_Sampling *pmasksam);
 void              evas_gl_common_shader_textures_bind(Evas_GL_Program *p, Eina_Bool recover_prog);
 
-Eina_Bool         evas_gl_common_file_cache_is_dir(const char *file);
-Eina_Bool         evas_gl_common_file_cache_mkdir(const char *dir);
 Eina_Bool         evas_gl_common_file_cache_file_exists(const char *file);
-Eina_Bool         evas_gl_common_file_cache_mkpath_if_not_exists(const char *path);
 Eina_Bool         evas_gl_common_file_cache_mkpath(const char *path);
 int               evas_gl_common_file_cache_dir_check(char *cache_dir, int num);
 int               evas_gl_common_file_cache_file_check(const char *cache_dir, const char *cache_name, char *cache_file, int dir_num);
