@@ -10,7 +10,6 @@
 #include "evas_xlib_color.h"
 #include "evas_xlib_image.h"
 #include "evas_xlib_dri_image.h"
-#include "evas_x_egl.h"
 
 #include "../software_generic/evas_native_common.h"
 
@@ -45,21 +44,13 @@ struct _Render_Engine
 };
 
 /* prototypes we will use here */
-static void        *_best_visual_get(int backend, void *connection, int screen);
-static unsigned int _best_colormap_get(int backend, void *connection, int screen);
-static int          _best_depth_get(int backend, void *connection, int screen);
+static void        *_best_visual_get(void *connection, int screen);
+static unsigned int _best_colormap_get(void *connection, int screen);
+static int          _best_depth_get(void *connection, int screen);
 
 static Eina_List *_outbufs = NULL;
 
 /* internal engine routines */
-static void
-_output_egl_shutdown(Render_Engine *re)
-{
-   if (!re->egl.disp) return;
-   _egl_x_win_surf_free(re->egl.disp, re->egl.surface);
-   _egl_x_disp_terminate(re->egl.disp);
-}
-
 static void *
 _output_xlib_setup(void *engine, int w, int h, int rot, Display *disp, Drawable draw,
                    Visual *vis, Colormap cmap, int depth, int debug,
@@ -165,34 +156,27 @@ on_error:
 }
 
 static void *
-_best_visual_get(int backend, void *connection, int screen)
+_best_visual_get(void *connection, int screen)
 {
    if (!connection) return NULL;
 
-   if (backend == EVAS_ENGINE_INFO_SOFTWARE_X11_BACKEND_XLIB)
-     return DefaultVisual((Display *)connection, screen);
-
-   return NULL;
+   return DefaultVisual((Display *)connection, screen);
 }
 
 static unsigned int
-_best_colormap_get(int backend, void *connection, int screen)
+_best_colormap_get(void *connection, int screen)
 {
    if (!connection) return 0;
 
-   if (backend == EVAS_ENGINE_INFO_SOFTWARE_X11_BACKEND_XLIB)
-     return DefaultColormap((Display *)connection, screen);
-   return 0;
+   return DefaultColormap((Display *)connection, screen);
 }
 
 static int
-_best_depth_get(int backend, void *connection, int screen)
+_best_depth_get(void *connection, int screen)
 {
    if (!connection) return 0;
 
-   if (backend == EVAS_ENGINE_INFO_SOFTWARE_X11_BACKEND_XLIB)
-     return DefaultDepth((Display *)connection, screen);
-   return 0;
+   return DefaultDepth((Display *)connection, screen);
 }
 
 static void
@@ -235,9 +219,6 @@ eng_output_setup(void *engine, void *in, unsigned int w, unsigned int h)
    static int try_swapbuf = -1;
    char *s;
 
-   if (info->info.backend != EVAS_ENGINE_INFO_SOFTWARE_X11_BACKEND_XLIB)
-     return NULL;
-
    if (try_swapbuf == -1)
      {
         if ((s = getenv("EVAS_NO_DRI_SWAPBUF")) != NULL)
@@ -285,9 +266,6 @@ eng_output_update(void *engine EINA_UNUSED, void *data, void *in, unsigned int w
    Render_Engine *re = data;
    Outbuf *ob = NULL;
 
-   if (info->info.backend != EVAS_ENGINE_INFO_SOFTWARE_X11_BACKEND_XLIB)
-     return 0;
-
    _outbufs = eina_list_remove(_outbufs, re->generic.ob);
 
    if (re->generic.outbuf_free == evas_software_xlib_swapbuf_free)
@@ -346,7 +324,6 @@ eng_output_free(void *engine, void *data)
      {
         _outbufs = eina_list_remove(_outbufs, re->generic.ob);
         evas_render_engine_software_generic_clean(engine, &re->generic);
-        _output_egl_shutdown(re);
         free(re);
      }
 }
