@@ -23,6 +23,7 @@ a way that this folder will be available on PYTHON_PATH, fe:
   from pyolian.generator import Template
 
 """
+import os
 from enum import IntEnum
 import atexit
 from ctypes import cast, byref, c_char_p, c_void_p, c_int
@@ -36,7 +37,30 @@ except ImportError:
 _already_halted = False
 
 
+# This is the same as the EOLIAN_FILE_FORMAT_VERSION macro
+file_format_version = lib.eolian_file_format_version_get()
+
+
 #  Eolian Enums  ##############################################################
+class Eolian_Object_Type(IntEnum):
+    UNKNOWN = 0
+    CLASS = 1
+    TYPEDECL = 2
+    STRUCT_FIELD = 3
+    ENUM_FIELD = 4
+    TYPE = 5
+    CONSTANT = 6
+    EXPRESSION = 7
+    FUNCTION = 8
+    FUNCTION_PARAMETER = 9
+    EVENT = 10
+    PART = 11
+    IMPLEMENT = 12
+    CONSTRUCTOR = 13
+    DOCUMENTATION = 14
+    ERROR = 15
+
+
 class Eolian_Function_Type(IntEnum):
     UNRESOLVED = 0
     PROPERTY = 1
@@ -333,11 +357,19 @@ class Eolian_Unit(EolianBaseObject):
     def file(self):
         return _str_to_py(lib.eolian_unit_file_get(self))
 
+    @cached_property
+    def file_path(self):
+        return _str_to_py(lib.eolian_unit_file_path_get(self))
+
     @cached_property
     def state(self):
         c_state = lib.eolian_unit_state_get(self)
         return Eolian_State(c_state) if c_state else None
 
+    @cached_property
+    def version(self):
+        return lib.eolian_unit_version_get(self)
+
     @property
     def objects(self):
         return Iterator(Object, lib.eolian_unit_objects_get(self))
@@ -485,6 +517,47 @@ class Eolian_State(Eolian_Unit):
         return Iterator(Typedecl,
                         lib.eolian_state_enums_by_file_get(self, _str_to_bytes(file_name)))
 
+    def state_check(self):
+        return bool(lib.eolian_state_check(self))
+
+
+#  Helper functions  ###################################################
+
+def parse_folders(folders):
+    """Loads a new database scanning the given folders.
+
+    For example:
+
+    SCAN_FOLDER = os.path.join(eolian.in_tree_src_dir(), 'src', 'lib')
+    eolian_db = eolian.parse_folders(SCAN_FOLDER)
+    """
+
+    db = Eolian_State()
+    if not isinstance(db, Eolian_State):
+        raise (RuntimeError('Eolian, failed to create Eolian state'))
+
+    if isinstance(folders, str):
+        folders = [folders]
+
+    for folder in folders:
+        # eolian source tree scan
+        if not db.directory_add(folder):
+            raise (RuntimeError('Eolian, failed to scan source dirsectory'))
+
+    # Parse all known eo files
+    if not db.all_eot_files_parse():
+        raise (RuntimeError('Eolian, failed to parse all EOT files'))
+
+    if not db.all_eo_files_parse():
+        raise (RuntimeError('Eolian, failed to parse all EO files'))
+
+    return db
+
+def in_tree_src_dir():
+    """Returns the root folder of this script's source tree"""
+    script_path = os.path.dirname(os.path.realpath(__file__))
+    return os.path.abspath(os.path.join(script_path, '..', '..', '..'))
+
 
 #  Namespace Utility Class  ###################################################
 
@@ -512,6 +585,10 @@ class Namespace(object):
     def __hash__(self):
         return hash(self._name)
 
+    @property
+    def unit(self):
+        return self._unit
+
     @property
     def name(self):
         return self._name
@@ -593,6 +670,10 @@ class Object(EolianBaseObject):
     def name(self):
         return _str_to_py(lib.eolian_object_name_get(self))
 
+    @cached_property
+    def c_name(self):
+        return _str_to_py(lib.eolian_object_c_name_get(self))
+
     @cached_property
     def short_name(self):
         return _str_to_py(lib.eolian_object_short_name_get(self))
@@ -690,6 +771,23 @@ class Class(Object):
     def extensions(self):
         return Iterator(Class, lib.eolian_class_extensions_get(self))
 
+    @cached_property
+    def extensions_hierarchy(self):
+        visited = set()
+        queue = [ext for ext in self.extensions]
+
+        while queue:
+            current = queue.pop()
+
+            if current in visited:
+                continue
+
+            visited.add(current)
+
+            queue.extend(current.extensions)
+
+        return visited
+
     @cached_property
     def inherits_full(self):
         li = []
@@ -697,6 +795,7 @@ class Class(Object):
         def do_class_recursive(cls):
             if cls.parent:
                 li.append(cls.parent)
+                do_class_recursive(cls.parent)
             for other in cls.extensions:
                 if other not in li:
                     li.append(other)
@@ -748,6 +847,10 @@ class Class(Object):
     def parts(self):
         return Iterator(Part, lib.eolian_class_parts_get(self))
 
+    @property
+    def requires(self):
+        return Iterator(Class, lib.eolian_class_requires_get(self))
+
 
 class Part(Object):
     def __repr__(self):
@@ -782,7 +885,7 @@ class Constructor(Object):
 
 class Event(Object):
     def __repr__(self):
-        return "<eolian.Event '{0.name}', c_name='{0.c_name}'>".format(self)
+        return "<eolian.Event '{0.name}', c_macro='{0.c_macro}'>".format(self)
 
     @cached_property
     def c_macro(self):
@@ -796,6 +899,11 @@ class Event(Object):
         c_type = lib.eolian_event_type_get(self)
         return Type(c_type) if c_type else None
 
+    @cached_property
+    def class_(self):
+        c_cls = lib.eolian_event_class_get(self)
+        return Class(c_cls) if c_cls else None
+
     @cached_property
     def documentation(self):
         c_doc = lib.eolian_event_documentation_get(self)
@@ -912,6 +1020,12 @@ class Function(Object):
         c_type = lib.eolian_function_return_type_get(self, ftype)
         return Type(c_type) if c_type else None
 
+    def return_c_type_get(self, ftype):
+        s = lib.eolian_function_return_c_type_get(self, ftype)
+        ret = _str_to_py(s)
+        lib.eina_stringshare_del(c_void_p(s))
+        return ret
+
     def return_default_value(self, ftype):
         c_expr = lib.eolian_function_return_default_value_get(self._obj, ftype)
         return Expression(c_expr) if c_expr else None
@@ -923,6 +1037,12 @@ class Function(Object):
     def return_allow_unused(self, ftype):
         return bool(lib.eolian_function_return_allow_unused(self, ftype))
 
+    def return_is_by_ref(self, ftype):
+        return bool(lib.eolian_function_return_is_by_ref(self, ftype))
+
+    def return_is_move(self, ftype):
+        return bool(lib.eolian_function_return_is_move(self, ftype))
+
     @cached_property
     def method_return_type(self):
         return self.return_type_get(Eolian_Function_Type.METHOD)
@@ -973,6 +1093,14 @@ class Function_Parameter(Object):
     def is_optional(self):
         return bool(lib.eolian_parameter_is_optional(self))
 
+    @cached_property
+    def is_by_ref(self):
+        return bool(lib.eolian_parameter_is_by_ref(self))
+
+    @cached_property
+    def is_move(self):
+        return bool(lib.eolian_parameter_is_move(self))
+
     @cached_property
     def type(self):
         c_type = lib.eolian_parameter_type_get(self)
@@ -983,26 +1111,46 @@ class Function_Parameter(Object):
         c_expr = lib.eolian_parameter_default_value_get(self)
         return Expression(c_expr) if c_expr else None
 
+    def c_type_get(self, as_return=False):
+        s = lib.eolian_parameter_c_type_get(self, as_return)
+        ret = _str_to_py(s)
+        lib.eina_stringshare_del(c_void_p(s))
+        return ret
+
 
 class Implement(Object):
     def __repr__(self):
         return "<eolian.Implement '{0.name}'>".format(self)
 
+    @cached_property
+    def parent(self):
+        c_impl = lib.eolian_aux_implement_parent_get(self)
+        return Implement(c_impl) if c_impl else None
+
     @cached_property
     def class_(self):
         c_cls = lib.eolian_implement_class_get(self)
         return Class(c_cls) if c_cls else None
 
+    @cached_property
+    def implementing_class(self):
+        c_cls = lib.eolian_implement_implementing_class_get(self)
+        return Class(c_cls) if c_cls else None
+
     @cached_property
     def function(self):
         c_func = lib.eolian_implement_function_get(self, None)
         return Function(c_func) if c_func else None
 
     def documentation_get(self, ftype=Eolian_Function_Type.METHOD):
-        # something strange in this eolian api :/  (see 'documentation' property
-        c_doc = lib.eolian_implement_documentation_get(self, ftype)
+        # c_doc = lib.eolian_implement_documentation_get(self, ftype)
+        c_doc = lib.eolian_aux_implement_documentation_get(self, ftype)
+        return Documentation(c_doc) if c_doc else None
+
+    @cached_property
+    def documentation_fallback(self):
+        c_doc = lib.eolian_aux_implement_documentation_fallback_get(self)
         return Documentation(c_doc) if c_doc else None
-    # TODO implement util properties for documentation_get
 
     def is_auto(self, ftype=Eolian_Function_Type.METHOD):
         return bool(lib.eolian_implement_is_auto(self, ftype))
@@ -1046,7 +1194,8 @@ class Type(Object):
     def builtin_type(self):
         return Eolian_Type_Builtin_Type(lib.eolian_type_builtin_type_get(self))
 
-    def c_type_get(self):
+    @cached_property
+    def c_type(self):
         s = lib.eolian_type_c_type_get(self)
         ret = _str_to_py(s)
         lib.eina_stringshare_del(c_void_p(s))
@@ -1085,6 +1234,10 @@ class Type(Object):
     def is_ptr(self):
         return bool(lib.eolian_type_is_ptr(self))
 
+    @cached_property
+    def is_move(self):
+        return bool(lib.eolian_type_is_move(self))
+
 
 class Typedecl(Object):
     def __repr__(self):
@@ -1154,7 +1307,7 @@ class Typedecl(Object):
 
 class Enum_Type_Field(Object):
     def __repr__(self):
-        return "<eolian.Enum_Type_Field '{0.name}', c_name='{0.c_name}'>".format(self)
+        return "<eolian.Enum_Type_Field '{0.name}', c_constant='{0.c_constant}'>".format(self)
 
     @cached_property
     def c_constant(self):
@@ -1182,7 +1335,22 @@ class Struct_Type_Field(Object):
     def type(self):
         c_type = lib.eolian_typedecl_struct_field_type_get(self)
         return Type(c_type) if c_type else None
-    
+
+    @cached_property
+    def c_type(self):
+        s = lib.eolian_typedecl_struct_field_c_type_get(self)
+        ret = _str_to_py(s)
+        lib.eina_stringshare_del(c_void_p(s))
+        return ret
+
+    @cached_property
+    def is_by_ref(self):
+        return bool(lib.eolian_typedecl_struct_field_is_by_ref(self))
+
+    @cached_property
+    def is_move(self):
+        return bool(lib.eolian_typedecl_struct_field_is_move(self))
+
     @cached_property
     def documentation(self):
         c_doc = lib.eolian_typedecl_struct_field_documentation_get(self)
@@ -1262,7 +1430,7 @@ class _Eolian_Doc_Token_Struct(ctypes.Structure):
                 ("text_end", c_char_p)]
 
 
-class Documentation(Object):  # OK (1 TODO Unit*)
+class Documentation(Object):
     def __repr__(self):
         t = self.summary if len(self.summary) < 40 else self.summary[:40] + '...'
         return "<eolian.Documentation summary='{}'>".format(t)
@@ -1293,8 +1461,7 @@ class Documentation(Object):  # OK (1 TODO Unit*)
         """ return a list of paragraphs, each one is a list of tokens """
         return self._tokenize(self.description)
 
-    @classmethod
-    def _tokenize(cls, full_text):
+    def _tokenize(self, full_text):
         paragraphs = []
         if not full_text:
             return paragraphs
@@ -1309,8 +1476,10 @@ class Documentation(Object):  # OK (1 TODO Unit*)
             while next_chunk:
                 typ = lib.eolian_doc_token_type_get(byref(tok))
                 txt = lib.eolian_doc_token_text_get(byref(tok))
-                #  ref =  # TODO ... Stupido parametro '*unit'  :(
-                tokens.append(Documentation_Token(typ, txt))
+                ref_obj = c_void_p(0)
+                ref_attr = c_void_p(0)
+                ref_type = lib.eolian_doc_token_ref_resolve(byref(tok), self.unit.state, byref(ref_obj), byref(ref_attr))
+                tokens.append(Documentation_Token(typ, txt, ref_type, ref_obj, ref_attr))
                 lib.free(c_void_p(txt))
                 next_chunk = lib.eolian_documentation_tokenize(c_char_p(next_chunk), byref(tok))
             paragraphs.append(tokens)
@@ -1319,10 +1488,12 @@ class Documentation(Object):  # OK (1 TODO Unit*)
 
 
 class Documentation_Token(object):
-    def __init__(self, c_token_type, c_text):
+    def __init__(self, c_token_type, c_text, c_ref_type, c_ref_obj, c_ref_attr):
         self._type = Eolian_Doc_Token_Type(c_token_type)
         self._text = _str_to_py(c_text)
-        self._ref = None  # TODO
+        self._ref_type = Eolian_Object_Type(c_ref_type)
+        self._ref_obj = Object(c_ref_obj) if c_ref_obj else None
+        self._ref_attr = Object(c_ref_attr) if c_ref_attr else None
 
     def __repr__(self):
         t = self.text if len(self.text) < 40 else self.text[:40] + '...'
@@ -1338,8 +1509,16 @@ class Documentation_Token(object):
         return self._text
 
     @property
-    def ref(self):
-        return self._ref
+    def ref_type(self):
+        return self._ref_type
+
+    @property
+    def ref_obj(self):
+        return self._ref_obj
+
+    @property
+    def ref_attr(self):
+        return self._ref_attr
 
 
 class Error(Object):
@@ -1382,42 +1561,23 @@ def _str_to_py(s):
 
 #  internal Object type -> Class mapping  #####################################
 
-class _Eolian_Object_Type(IntEnum):
-    UNKNOWN = 0
-    CLASS = 1
-    TYPEDECL = 2
-    STRUCT_FIELD = 3
-    ENUM_FIELD = 4
-    TYPE = 5
-    CONSTANT = 6
-    EXPRESSION = 7
-    FUNCTION = 8
-    FUNCTION_PARAMETER = 9
-    EVENT = 10
-    PART = 11
-    IMPLEMENT = 12
-    CONSTRUCTOR = 13
-    DOCUMENTATION = 14
-    ERROR = 15
-
-
 _eolian_type_class_mapping = {
-    _Eolian_Object_Type.UNKNOWN: Object,
-    _Eolian_Object_Type.CLASS: Class,
-    _Eolian_Object_Type.TYPEDECL: Typedecl,
-    _Eolian_Object_Type.STRUCT_FIELD: Struct_Type_Field,
-    _Eolian_Object_Type.ENUM_FIELD: Enum_Type_Field,
-    _Eolian_Object_Type.TYPE: Type,
-    _Eolian_Object_Type.CONSTANT: Constant,
-    _Eolian_Object_Type.EXPRESSION: Expression,
-    _Eolian_Object_Type.FUNCTION: Function,
-    _Eolian_Object_Type.FUNCTION_PARAMETER: Function_Parameter,
-    _Eolian_Object_Type.EVENT: Event,
-    _Eolian_Object_Type.PART: Part,
-    _Eolian_Object_Type.IMPLEMENT: Implement,
-    _Eolian_Object_Type.CONSTRUCTOR: Constructor,
-    _Eolian_Object_Type.DOCUMENTATION: Documentation,
-    _Eolian_Object_Type.ERROR: Error,
+    Eolian_Object_Type.UNKNOWN: Object,
+    Eolian_Object_Type.CLASS: Class,
+    Eolian_Object_Type.TYPEDECL: Typedecl,
+    Eolian_Object_Type.STRUCT_FIELD: Struct_Type_Field,
+    Eolian_Object_Type.ENUM_FIELD: Enum_Type_Field,
+    Eolian_Object_Type.TYPE: Type,
+    Eolian_Object_Type.CONSTANT: Constant,
+    Eolian_Object_Type.EXPRESSION: Expression,
+    Eolian_Object_Type.FUNCTION: Function,
+    Eolian_Object_Type.FUNCTION_PARAMETER: Function_Parameter,
+    Eolian_Object_Type.EVENT: Event,
+    Eolian_Object_Type.PART: Part,
+    Eolian_Object_Type.IMPLEMENT: Implement,
+    Eolian_Object_Type.CONSTRUCTOR: Constructor,
+    Eolian_Object_Type.DOCUMENTATION: Documentation,
+    Eolian_Object_Type.ERROR: Error,
 }
 
 
@@ -1447,34 +1607,57 @@ if __name__ == '__main__':
 
     # prepare the two regexp
     flags = re.S | re.M
-    DEFINED_RE = re.compile('^EAPI[\w\n *]*(eolian_\w*)\([\w *,]*\);', flags)
-    USED_RE = re.compile('lib\.(eolian_[\w]*)\(', flags)
+    FUNC_DEFINED_RE = re.compile(r'^\s*EAPI[\w\s*]*(eolian_\w*)\s*\([\w\s*,]*\);', flags)
+    FUNC_USED_RE = re.compile(r'^[^\n#]*lib\.(eolian_[\w]*)\s*\(', flags)
 
-    # extract all EAPI functions from Eolian.h
+    ENUM_DEFINED_RE = re.compile(r'typedef enum\s*{([^}]*)}\s*(Eolian_[\w]*);', flags)
+    ENUM_USED_RE = re.compile(r'^class\s([\w]*)\(IntEnum\):', flags)
+
+    # ignore some know cases (function or enum)
+    IGNORED = {
+        'eolian_implement_documentation_get',  # we are using eolian_aux_implement_documentation_get
+        'eolian_documentation_string_split',  # not needed in python
+    }
+
+    # extract functions and enums from Eolian.h
     defined_funcs = []
+    defined_enums = []
     with open(eolian_header, 'r') as fh:
         header = fh.read()
-        for match in re.finditer(DEFINED_RE, header):
-            func_name = match.group(1)
+    for match in re.finditer(FUNC_DEFINED_RE, header):
+        func_name = match.group(1)
+        if func_name not in IGNORED:
             defined_funcs.append(func_name)
+    for match in re.finditer(ENUM_DEFINED_RE, header):
+        enum_name = match.group(2)
+        if enum_name not in IGNORED:
+            defined_enums.append(enum_name)
     defined_funcs = set(defined_funcs)
+    defined_enums = set(defined_enums)
 
-    # extract all called functions in eolian.py (this file)
+    # extract functions and enums from eolian.py (this file)
     used_funcs = []
+    used_enums = []
     with open(__file__, 'r') as fh:
         source = fh.read()
-        for match in re.finditer(USED_RE, source):
-            func_name = match.group(1)
-            used_funcs.append(func_name)
+    for match in re.finditer(FUNC_USED_RE, source):
+        func_name = match.group(1)
+        used_funcs.append(func_name)
+    for match in re.finditer(ENUM_USED_RE, source):
+        enum_name = match.group(1)
+        used_enums.append(enum_name)
     used_funcs = set(used_funcs)
+    used_enums = set(used_enums)
 
     # show general info
-    num_def = len(defined_funcs)
-    num_usd = len(used_funcs)
+    num_def, num_usd = len(defined_funcs), len(used_funcs)
+    num_enum_def, num_enum_usd = len(defined_enums), len(used_enums)
     print('Pyolian coverage results')
     print('========================')
     print('Found %d functions defined in Eolian.h (%s)' % (num_def, eolian_header))
-    print('Found %d functions used in eolian.py (hopefully not commented out)' % num_usd)
+    print('Found %d functions used in eolian.py (hopefully not multiline-commented)' % num_usd)
+    print('Found %d enums defined in Eolian.h' % num_enum_def)
+    print('Found %d enums defined in eolian.py' % num_enum_usd)
     print('Total API coverage %.1f%%' % (num_usd / num_def * 100))
     print()
 
@@ -1486,15 +1669,31 @@ if __name__ == '__main__':
         print('{:02d}. {}'.format(i, func_name))
     print()
 
-    # List all functions found in Eolian.h  (--all option)
-    if '--all' in sys.argv:
-        print('{} functions found in Eolian.h'.format(num_def))
-        print('===============================')
-        for i, func_name in enumerate(sorted(defined_funcs), 1):
-            print('{:03d}. {}'.format(i, func_name))
+    # list all missing enums
+    missing = defined_enums - used_enums
+    if len(missing) > 0:
+        print('{} Missing enums in eolian.py'.format(len(missing)))
+        print('=================================')
+        for i, enum_name in enumerate(sorted(missing), 1):
+            print('{:02d}. {}'.format(i, enum_name))
         print()
+
+    # List all functions found in C and Py (--all option)
+    if '--all' in sys.argv:
+        to_list = (
+            (defined_funcs, '{} EAPI functions defined in Eolian.h'),
+            (used_funcs, '{} functions called in eolian.py'),
+            (defined_enums, '{} Enums defined in Eolian.h'),
+            (used_enums, '{} Enums defined in eolian.py'),
+        )
+        for bag, label in to_list:
+            print(label.format(len(bag)))
+            print('==============================')
+            for i, obj_name in enumerate(sorted(bag), 1):
+                print('{:03d}. {}'.format(i, obj_name))
+            print()
     else:
         print('Additional arguments')
         print('====================')
-        print(' --all   To list all functions found in Eolian.h')
+        print(' --all   To list all functions and enums found')
         print()
