@@ -17,6 +17,7 @@ using System;
 using System.Linq;
 using System.Collections.Generic;
 using System.Reflection;
+using System.Diagnostics.CodeAnalysis;
 
 namespace TestSuite
 {
@@ -28,6 +29,7 @@ class TestEo
         var testing = new Dummy.TestObject();
         var o1 = testing.ReturnNullObject();
         Test.Assert(o1 == null);
+        testing.Dispose();
     }
 
     //
@@ -42,6 +44,7 @@ class TestEo
         var o2 = o1.ReturnObject();
         Test.Assert(o2.NativeHandle != IntPtr.Zero);
         Test.Assert(o2.NativeHandle == o1.NativeHandle);
+        testing.Dispose();
     }
     /* Commented out as adding the event listener seems to prevent it from being GC'd.
     public static void destructor_really_frees()
@@ -121,12 +124,13 @@ class TestEoInherit
     {
         Efl.Object loop = new MyObject();
         Test.Assert(loop.NativeHandle != System.IntPtr.Zero);
+        loop.Dispose();
     }
 
+    [SuppressMessage("Microsoft.Reliability", "CA2000:DisposeObjectBeforeLosingScope", Justification = "It is expected to lose scope.")]
     private static WeakReference CreateCollectableInherited()
     {
-        var obj = new MyObject();
-        return new WeakReference(obj);
+        return new WeakReference(new MyObject());
     }
 
     public static void inherited_collected()
@@ -145,8 +149,9 @@ class TestEoNames
         var obj = new Dummy.TestObject();
 
         string name = "Dummy";
-        obj.SetName(name);
-        Test.AssertEquals(name, obj.GetName());
+        obj.Name = name;
+        Test.AssertEquals(name, obj.Name);
+        obj.Dispose();
     }
 }
 
@@ -157,10 +162,12 @@ class TestEoParent
         var parent = new Dummy.TestObject(null);
         var child = new Dummy.TestObject(parent);
 
-        Test.AssertEquals(parent, child.GetParent());
+        Test.AssertEquals(parent, child.Parent);
 
-        var parent_retrieved = child.GetParent() as Dummy.TestObject;
+        var parent_retrieved = child.Parent as Dummy.TestObject;
         Test.AssertEquals(parent, parent_retrieved);
+        child.Dispose();
+        parent.Dispose();
     }
 
     public static void parent_inherited_class()
@@ -168,10 +175,12 @@ class TestEoParent
         Dummy.Numberwrapper parent = new Dummy.Numberwrapper(null);
         var child = new Dummy.TestObject(parent);
 
-        Test.AssertEquals(parent, child.GetParent());
+        Test.AssertEquals(parent, child.Parent);
 
-        Dummy.Numberwrapper parent_retrieved = child.GetParent() as Dummy.Numberwrapper;
+        Dummy.Numberwrapper parent_retrieved = child.Parent as Dummy.Numberwrapper;
         Test.AssertEquals(parent, parent_retrieved);
+        child.Dispose();
+        parent.Dispose();
     }
 
     private class Derived : Dummy.TestObject
@@ -186,10 +195,12 @@ class TestEoParent
         var parent = new Derived(null);
         var child = new Derived(parent);
 
-        Test.AssertEquals(parent, child.GetParent());
+        Test.AssertEquals(parent, child.Parent);
 
-        var parent_from_cast = child.GetParent() as Derived;
+        var parent_from_cast = child.Parent as Derived;
         Test.AssertEquals(parent, parent_from_cast);
+        child.Dispose();
+        parent.Dispose();
     }
 }
 
@@ -198,15 +209,15 @@ class TestKlassMethods
     public static void basic_class_method()
     {
         int reference = 0xbeef;
-        Dummy.TestObject.SetKlassProp(reference);
-        Test.AssertEquals(reference, Dummy.TestObject.GetKlassProp());
+        Dummy.TestObject.KlassProp = reference;
+        Test.AssertEquals(reference, Dummy.TestObject.KlassProp);
     }
 
     public static void inherited_class_method()
     {
         int reference = 0xdead;
-        Dummy.Child.SetKlassProp(reference);
-        Test.AssertEquals(reference, Dummy.Child.GetKlassProp());
+        Dummy.Child.KlassProp = reference;
+        Test.AssertEquals(reference, Dummy.Child.KlassProp);
     }
 }
 
@@ -222,7 +233,7 @@ class TestTypedefs
 
         Test.AssertEquals((Dummy.MyInt)ret, input);
         Test.AssertEquals(receiver, input);
-
+        obj.Dispose();
     }
 }
 
@@ -246,22 +257,70 @@ class TestVariables
 
 class TestEoAccessors
 {
-    public static void basic_eo_accessors()
+    private static void do_eo_accessors(IEnumerable<int> accessor, bool shouldMove=false)
     {
         var obj = new Dummy.TestObject();
-        Eina.List<int> lst = new Eina.List<int>();
-        lst.Append(4);
-        lst.Append(3);
-        lst.Append(2);
-        lst.Append(5);
-        Eina.Accessor<int> acc = obj.CloneAccessor(lst.GetAccessor());
 
-        var zipped = acc.Zip(lst, (first, second) => new Tuple<int, int>(first, second));
+        IEnumerable<int> source = shouldMove ? accessor.ToList() : accessor;
+
+        IEnumerable<int> acc = shouldMove ? obj.CloneAccessorOwn(accessor) : obj.CloneAccessor(accessor);
+
+        var zipped = acc.Zip(source, (first, second) => new Tuple<int, int>(first, second));
 
         foreach (Tuple<int, int> pair in zipped)
         {
             Test.AssertEquals(pair.Item1, pair.Item2);
         }
+
+        obj.Dispose();
+    }
+
+    public static void eina_eo_accessors()
+    {
+        Eina.List<int> lst = new Eina.List<int>();
+        lst.Append(4);
+        lst.Append(3);
+        lst.Append(2);
+        lst.Append(5);
+
+        do_eo_accessors(lst.GetAccessor());
+
+        lst.Dispose();
+    }
+    public static void eina_eo_accessors_own()
+    {
+        Eina.List<int> lst = new Eina.List<int>();
+        lst.Append(4);
+        lst.Append(3);
+        lst.Append(2);
+        lst.Append(1);
+        Eina.Accessor<int> acc = lst.GetAccessor();
+        do_eo_accessors(acc, shouldMove : true);
+
+        Test.Assert(acc.Own);
+
+    }
+
+    public static void managed_eo_accessors()
+    {
+        List<int> lst = new List<int>();
+        lst.Add(-1);
+        lst.Add(1);
+        lst.Add(4);
+        lst.Add(42);
+
+        do_eo_accessors(lst);
+    }
+
+    public static void managed_eo_accessors_own()
+    {
+        List<int> lst = new List<int>();
+        lst.Add(-1);
+        lst.Add(1);
+        lst.Add(4);
+        lst.Add(42);
+
+        do_eo_accessors(lst, shouldMove : true);
     }
 }
 
@@ -282,6 +341,7 @@ class TestEoFinalize
     {
         Inherit inherit = new Inherit();
         Test.Assert(inherit.finalizeCalled);
+        inherit.Dispose();
     }
 }
 
@@ -315,13 +375,26 @@ class TestEoMultipleChildClasses
         SecondChild obj2 = new SecondChild();
         Test.AssertEquals(2, obj2.receivedValue);
 
+        obj.Dispose();
         obj = new FirstChild();
         Test.AssertEquals(1, obj.receivedValue);
+        obj2.Dispose();
+        obj.Dispose();
     }
 }
 
 class TestCsharpProperties
 {
+
+    private class MyObject : Dummy.TestObject
+    {
+        public MyObject(Efl.Object parent = null) : base(parent)
+        {
+        }
+        private MyObject(ConstructingHandle ch) : base(ch)
+        {
+        }
+    }
     public static void test_csharp_properties()
     {
         var obj = new Dummy.TestObject();
@@ -329,12 +402,14 @@ class TestCsharpProperties
         obj.Name = name;
 
         Test.AssertEquals(name, obj.Name);
+        obj.Dispose();
     }
 
     public static void test_getter_only()
     {
         var obj = new Dummy.TestObject();
         Test.Assert(!obj.Invalidating);
+        obj.Dispose();
     }
 
     public static void test_setter_only()
@@ -342,8 +417,9 @@ class TestCsharpProperties
         var obj = new Dummy.TestObject();
         int val = -1984;
 
-        obj.SetterOnly = val;
+        obj.SetSetterOnly(val);
         Test.AssertEquals(val, obj.GetSetterOnly());
+        obj.Dispose();
     }
 
     public static void test_class_property()
@@ -359,6 +435,29 @@ class TestCsharpProperties
         Dummy.ITestIface iface = new Dummy.TestObject();
         iface.IfaceProp = val;
         Test.AssertEquals(val, iface.IfaceProp);
+        iface.Dispose();
+    }
+
+    public static void test_iface_value_property()
+    {
+        var obj = new Dummy.TestObject();
+        var prop = new MyObject();
+
+        obj.IfaceValueProp = prop;
+        Test.AssertEquals(obj.IfaceValueProp, prop);
+
+        obj.Dispose();
+        prop.Dispose();
+    }
+
+    public static void test_iface_value_from_c()
+    {
+        var obj = new Dummy.TestObject();
+
+        obj.SetIfaceKlassProp(typeof(MyObject));
+        Test.AssertEquals(obj.IfaceValueFromC.GetType(), typeof(MyObject));
+
+        obj.Dispose();
     }
 
     public static void test_csharp_multi_valued_prop()
@@ -367,6 +466,28 @@ class TestCsharpProperties
         obj.MultiValuedProp = (1, 2);
         var ret = obj.MultiValuedProp;
         Test.AssertEquals(ret, (1, 2));
+        obj.Dispose();
+    }
+
+    public static void test_csharp_return_type_get_prop ()
+    {
+        var obj = new Dummy.TestObject();
+        obj.ReturnTypeGetProp = 5;
+        var i = obj.ReturnTypeGetProp;
+    }
+
+    public static void test_csharp_return_type_set_prop ()
+    {
+        var obj = new Dummy.TestObject();
+        obj.ReturnTypeSetProp = 5;
+        var i = obj.ReturnTypeSetProp;
+    }
+
+    public static void test_csharp_return_type_prop ()
+    {
+        var obj = new Dummy.TestObject();
+        obj.ReturnTypeProp = 5;
+        var i = obj.ReturnTypeProp;
     }
 }
 
@@ -386,6 +507,7 @@ class TestEoGrandChildrenFinalize
     {
         Child obj = new Child();
         Test.AssertEquals(42, obj.receivedValue);
+        obj.Dispose();
     }
 
     public sealed class GrandChild : Dummy.Child
@@ -409,6 +531,7 @@ class TestEoGrandChildrenFinalize
     {
         GrandChild obj = new GrandChild();
         Test.AssertEquals(-42, obj.receivedValue);
+        obj.Dispose();
     }
 }
 
@@ -429,7 +552,7 @@ class TestConstructors
         var obj = new Dummy.Child(null, a, b, iface_prop);
 #endif
         Test.AssertEquals(iface_prop, obj.IfaceProp);
-
+        obj.Dispose();
 #if EFL_BETA
         obj = new Dummy.Child(parent: null, ifaceProp : iface_prop, doubleParamsA : a, doubleParamsB : b,
                               obligatoryBetaCtor : beta,
@@ -443,6 +566,7 @@ class TestConstructors
         Test.Assert(obj.ObligatoryBetaCtorWasCalled);
         Test.Assert(obj.OptionalBetaCtorWasCalled);
 #endif
+        obj.Dispose();
     }
 
     public static void test_optional_constructor()
@@ -456,7 +580,8 @@ class TestConstructors
 #else
         var obj = new Dummy.Child(null, a, b);
 #endif
-        Test.Assert(!obj.GetIfaceWasSet());
+        Test.Assert(!obj.IfaceWasSet);
+        obj.Dispose();
     }
 }
 
@@ -470,6 +595,7 @@ class TestInterfaceConcrete
 
         iface.IfaceProp = 1970;
         Test.AssertEquals(iface.IfaceProp, 1970);
+        obj.Dispose();
     }
 }
 
@@ -481,13 +607,14 @@ class TestProvider
         var obj = new Dummy.TestObject();
         Dummy.Numberwrapper provider = obj.FindProvider(typeof(Dummy.Numberwrapper)) as Dummy.Numberwrapper;
         Test.AssertEquals(provider.GetType(), typeof(Dummy.Numberwrapper));
-        Test.AssertEquals(provider.GetNumber(), 1999);
+        Test.AssertEquals(provider.Number, 1999);
+        obj.Dispose();
     }
 
     private class ProviderHolder : Dummy.TestObject
     {
         private Dummy.TestObject provider;
-        public string ProviderName
+        public static string ProviderName
         {
             get
             {
@@ -498,7 +625,7 @@ class TestProvider
         public ProviderHolder() : base(null)
         {
             this.provider = new Dummy.TestObject(this);
-            this.provider.Name = this.ProviderName;
+            this.provider.Name = ProviderHolder.ProviderName;
             this.provider.IfaceProp = 1997;
         }
 
@@ -525,8 +652,8 @@ class TestProvider
 
         provider = obj.CallFindProviderForIface();
         Test.AssertNotNull(provider, msg : "Provider of ITestIFace must not be null");
-        Test.AssertEquals(provider.Name, obj.ProviderName, "Provider name does not match expected");
-
+        Test.AssertEquals(provider.Name, ProviderHolder.ProviderName, "Provider name does not match expected");
+        obj.Dispose();
     }
 }
 
@@ -542,6 +669,7 @@ class TestObjectDeletion
         part.Del();
 
         Test.AssertNull(obj.OnePart);
+        obj.Dispose();
     }
 }
 
@@ -564,28 +692,30 @@ class TestProtectedInterfaceMembers
     {
         var obj = new Dummy.TestObject();
         Test.AssertEquals(obj.CallMethodProtected(42), -42);
+        obj.Dispose();
     }
 
     public static void test_protected_interface_in_inherited_class_called_from_c()
     {
         var obj = new MyObject();
         Test.AssertEquals(obj.CallMethodProtected(42), 42 * 42);
+        obj.Dispose();
     }
 
     public static void test_interface_skipped_protected()
     {
         var type = typeof(Dummy.ITestIface);
         var methods = type.GetMethods(BindingFlags.Public | BindingFlags.Instance);
+        var properties = type.GetProperties(BindingFlags.Public | BindingFlags.Instance);
 
         // Fully protected property
         Test.AssertNull(methods.SingleOrDefault(m => m.Name == "GetProtectedProp"));
         Test.AssertNull(methods.SingleOrDefault(m => m.Name == "SetProtectedProp"));
 
         // Partially protected property
-        Test.AssertNotNull(methods.SingleOrDefault(m => m.Name == "GetPublicGetterPrivateSetter"));
+        Test.AssertNotNull(properties.SingleOrDefault(m => m.Name == "PublicGetterPrivateSetter"));
         Test.AssertNull(methods.SingleOrDefault(m => m.Name == "SetPublicGetterPrivateSetter"));
 
-        var properties = type.GetProperties(BindingFlags.Public | BindingFlags.Instance);
         Test.AssertNull(properties.SingleOrDefault(m => m.Name == "ProtectedProp"));
         Test.AssertNotNull(properties.SingleOrDefault(m => m.Name == "PublicGetterPrivateSetter"));
     }
@@ -594,15 +724,16 @@ class TestProtectedInterfaceMembers
     {
         var type = typeof(Dummy.TestObject);
 
-        // Fully protected property
-        var protected_methods = type.GetMethods(BindingFlags.NonPublic | BindingFlags.Instance).Where(m => m.IsFamily);
-        Test.AssertNotNull(protected_methods.SingleOrDefault(m => m.Name == "GetProtectedProp"));
-        Test.AssertNotNull(protected_methods.SingleOrDefault(m => m.Name == "SetProtectedProp"));
+        // Fully internal property
+        var internal_methods = type.GetMethods(BindingFlags.NonPublic | BindingFlags.Instance).Where(m => m.IsAssembly);
+        Test.AssertNotNull(internal_methods.SingleOrDefault(m => m.Name == "GetProtectedProp"));
+        Test.AssertNotNull(internal_methods.SingleOrDefault(m => m.Name == "SetProtectedProp"));
 
         // Partially protected property
         var public_methods = type.GetMethods(BindingFlags.Public | BindingFlags.Instance);
-        Test.AssertNotNull(public_methods.SingleOrDefault(m => m.Name == "GetPublicGetterPrivateSetter"));
-        Test.AssertNotNull(protected_methods.SingleOrDefault(m => m.Name == "SetPublicGetterPrivateSetter"));
+        Test.AssertNull(public_methods.SingleOrDefault(m => m.Name == "GetPublicGetterPrivateSetter"));
+        Test.AssertNotNull(internal_methods.SingleOrDefault(m => m.Name == "GetPublicGetterPrivateSetter"));
+        Test.AssertNotNull(internal_methods.SingleOrDefault(m => m.Name == "SetPublicGetterPrivateSetter"));
 
         var protected_properties = type.GetProperties(BindingFlags.NonPublic | BindingFlags.Instance);
         var prop = protected_properties.SingleOrDefault(m => m.Name == "ProtectedProp");
@@ -640,6 +771,43 @@ class TestHiddenClasses
         var hidden = obj.HiddenObject;
 
         Test.AssertEquals(hidden.Name, "hidden_object");
+        obj.Dispose();
+    }
+}
+
+class TestAliasEquality
+{
+    static Dummy.MyInt a = 4;
+    static Dummy.MyInt b = 4;
+    static Dummy.MyInt c = 5;
+
+    public static void test_equals()
+    {
+        Test.AssertEquals(a, b);
+        Test.AssertNotEquals(a, c);
+    }
+
+    public static void test_equals_different_types()
+    {
+        Test.Assert(!(a.Equals(new Object())));
+    }
+
+    public static void test_equatable()
+    {
+        Test.Assert(((IEquatable<Dummy.MyInt>)a).Equals(b));
+        Test.Assert(!((IEquatable<Dummy.MyInt>)a).Equals(c));
+    }
+
+    public static void test_equality_operators()
+    {
+        Test.Assert(a == b);
+        Test.Assert(a != c);
+    }
+
+    public static void test_hash_code()
+    {
+        Test.AssertEquals(a.GetHashCode(), b.GetHashCode());
+        Test.AssertNotEquals(a.GetHashCode(), c.GetHashCode());
     }
 }
 
