@@ -59,27 +59,30 @@ _test_free(Eina_Lazy_Allocator_Test *elat)
 
 EFL_START_TEST(eina_lalloc_simple)
 {
-   Eina_Lazy_Allocator_Test *elat;
-   Eina_Lalloc *test;
-   int i;
+  Eina_Lazy_Allocator_Test *elat;
+  Eina_Lalloc *test;
+  int i;
 
-   elat = calloc(1, sizeof (Eina_Lazy_Allocator_Test));
-      fail_if(!elat);
+  elat = calloc(1, sizeof (Eina_Lazy_Allocator_Test));
+  fail_if(!elat);
 
-   test = eina_lalloc_new(elat, EINA_LALLOC_ALLOC(
-                             _test_alloc), EINA_LALLOC_FREE(_test_free), 10);
-      fail_if(!test);
+  test = eina_lalloc_new(elat,
+                         EINA_LALLOC_ALLOC(_test_alloc),
+                         EINA_LALLOC_FREE(_test_free), 10);
+  fail_if(!test);
 
-   for (i = 0; i < 10; ++i)
-      fail_if(eina_lalloc_element_add(test) != EINA_TRUE);
-      fail_if(eina_lalloc_element_add(test) != EINA_FALSE);
-      fail_if(eina_lalloc_elements_add(test, 5) != EINA_TRUE);
-   for (i = 0; i < 21; ++i)
-      fail_if(eina_lalloc_element_add(test) != EINA_TRUE);
+  for (i = 0; i < 10; ++i)
+    fail_if(eina_lalloc_element_add(test) != EINA_TRUE);
 
-      fail_if(eina_lalloc_elements_add(test, 50) != EINA_FALSE);
+  fail_if(eina_lalloc_element_add(test) != EINA_FALSE);
+  fail_if(eina_lalloc_elements_add(test, 5) != EINA_TRUE);
 
-      eina_lalloc_free(test);
+  for (i = 0; i < 21; ++i)
+    fail_if(eina_lalloc_element_add(test) != EINA_TRUE);
+
+  fail_if(eina_lalloc_elements_add(test, 50) != EINA_FALSE);
+
+  eina_lalloc_free(test);
 }
 EFL_END_TEST
 
