@@ -14,12 +14,13 @@ static const Efl_Test_Case etc[] = {
   { "efl_ui_config", efl_ui_test_config},
   { "efl_ui_focus", efl_ui_test_focus},
   { "efl_ui_focus_sub", efl_ui_test_focus_sub},
+  { "efl_ui_gesture", efl_ui_test_gesture},
   { "efl_ui_box", efl_ui_test_box},
   { "efl_ui_box_flow", efl_ui_test_box_flow},
   { "efl_ui_box_stack", efl_ui_test_box_stack},
   { "efl_ui_table", efl_ui_test_table},
   { "efl_ui_grid", efl_ui_test_grid},
-  { "efl_ui_relative_layout", efl_ui_test_relative_layout},
+  { "efl_ui_relative_container", efl_ui_test_relative_container},
   { "efl_ui_image", efl_ui_test_image},
   { "efl_ui_image_zoomable", efl_ui_test_image_zoomable},
   { "efl_ui_layout", efl_ui_test_layout},
@@ -38,13 +39,18 @@ static const Efl_Test_Case etc[] = {
   { "efl_ui_collection", efl_ui_test_item_container },
   { "efl_ui_grid_container", efl_ui_test_grid_container },
   { "efl_ui_list_container", efl_ui_test_list_container },
+  { "efl_ui_collection_view", efl_ui_test_collection_view },
   { "efl_ui_select_model", efl_ui_test_select_model },
   { "efl_ui_view_model", efl_ui_test_view_model },
   { "efl_ui_group_item", efl_ui_test_group_item },
+  { "efl_ui_text", efl_ui_test_text},
+#ifdef BUILD_VG_LOADER_JSON
+  { "efl_ui_vg_animation", efl_ui_test_vg_animation},
+#endif
   { NULL, NULL }
 };
 
-EFL_CLASS_SIMPLE_CLASS(efl_ui_widget, "efl_ui_widget", EFL_UI_WIDGET_CLASS);
+EFL_CLASS_SIMPLE_CLASS(efl_ui_widget, "Efl.Ui.Widget", EFL_UI_WIDGET_CLASS);
 
 int
 main(int argc, char **argv)
