@@ -1,5 +1,5 @@
-#ifndef _EOLIAN_IMPORT_TYPES_H_
-#define _EOLIAN_IMPORT_TYPES_H_
+#ifndef _EOLIAN_IMPORT_TYPES_EOT_H_
+#define _EOLIAN_IMPORT_TYPES_EOT_H_
 
 #ifndef _IMPORT_TYPES_EOT_TYPES
 #define _IMPORT_TYPES_EOT_TYPES
