@@ -20,7 +20,7 @@
 # include "config.h"
 #endif
 
-#include <Evil.h>
+#include <evil_private.h>
 
 #include "evil_suite.h"
 
